(***********************************************************************



                    Mathematica-Compatible Notebook



This notebook can be used on any computer system with Mathematica 3.0,

MathReader 3.0, or any compatible application. The data for the notebook 

starts with the line of stars above.



To get the notebook into a Mathematica-compatible application, do one of 

the following:



* Save the data starting with the line of stars above into a file

  with a name ending in .nb, then open the file inside the application;



* Copy the data starting with the line of stars above to the

  clipboard, then use the Paste menu command inside the application.



Data for notebooks contains only printable 7-bit ASCII and can be

sent directly in email or through ftp in text mode.  Newlines can be

CR, LF or CRLF (Unix, Macintosh or MS-DOS style).



NOTE: If you modify the data for this notebook not in a Mathematica-

compatible application, you must delete the line below containing the 

word CacheID, otherwise Mathematica-compatible applications may try to 

use invalid cache data.



For more information on notebooks and Mathematica-compatible 

applications, contact Wolfram Research:

  web: http://www.wolfram.com

  email: info@wolfram.com

  phone: +1-217-398-0700 (U.S.)



Notebook reader applications are available free of charge from 

Wolfram Research.

***********************************************************************)



(*CacheID: 232*)





(*NotebookFileLineBreakTest

NotebookFileLineBreakTest*)

(*NotebookOptionsPosition[    138301,       4804]*)

(*NotebookOutlinePosition[    139194,       4835]*)

(*  CellTagsIndexPosition[    139150,       4831]*)

(*WindowFrame->Normal*)







Notebook[{

Cell["\<\

 Iterative Solution of Highly Nonlinear Differential Equations Using \

Mathematica\

\>", "Title",

  TextAlignment->Center],



Cell["\<\

 Frank Kampas

Lockheed Martin*\

\>", "Subtitle",

  TextAlignment->Center],



Cell["\<\

 The  work presented here is not related to the author's  work for Lockheed \

Martin\

\>", "Text"],



Cell[" Introduction", "Subtitle",

  TextAlignment->Center,

  FontSlant->"Italic"],



Cell[TextData[{

  " Nonlinear boundary value differential equations are usually solved with \

the \"shooting method\".  In this technique, the initial conditions are \

adjusted until the boundary conditions at the other boundary are satisified.  \

In situations in which the shooting method fails, the iterative \

\"relaxation\" method can be used.  Initial guesses at the solution are \

improved repeatedly.  The relaxation method can be implement using \

\"quasi-linearization\".  The differential equation is linearized about the \

guessed solution and the linearized boundary value problem is solved.  This \

technique can be implemented in a very straight-forward fashion in ",

  StyleBox["Mathematica",

    FontSlant->"Italic"],

  " because the numerical solutions to differential equations are \

interpolating functions.\n\nQuasi-linearization is first demonstrated with a \

single differential equation and then with the 5 coupled differential \

equations which describe a p-n junction.   "

}], "Text"],



Cell[CellGroupData[{



Cell["Troesch's Equation", "Subtitle",

  TextAlignment->Center,

  FontSlant->"Italic"],



Cell["\<\

 The shooting method fails for Troesch's equation, y'' = 5 Sinh(5 y), y(0)=0, \

y(1) =1, where the solution has a singularity at approximately at x = 1.03, \

unless the initial estimate of the value of the derivative at x = 0 is very \

good.  In the following calculation, shootsoln[d_] is the solution to \

Troesch's equation, as a function of d, which is equal to y'(0).  FindRoot is \

used to find the value of d for which the solution satisfies the boundry \

condition at x = 1.  The function s is the solution.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(shootsoln[d_] := 

      \(NDSolve[{\(\(y'\)'\)[x] - 5\ Sinh[5\ y[x]] == 0, y[0] == 0, 

            \(y'\)[0] == d}, y, {x, 0, 1}]\)[\([1]\)]; \n

    soln = y\  /. \n\t\t

        Module[{s}, \n\t\t\t\t

          FindRoot[\((y[1] /. \ \((s = shootsoln[d])\))\) == 1, {d, 0, 1}]; s]

          \)], "Input"],



Cell[BoxData[

    \(NDSolve::"ndsz" \( : \ \) 

      "At \!\(x\) == \!\(0.43129882432337574`\), step size is effectively \

zero; singularity suspected."\)], "Message"],



Cell[BoxData[

    TagBox[\(InterpolatingFunction[{{0.`, 1.`}}, "<>"]\),

      False,

      Editable->False]], "Output"]

}, Open  ]],



Cell["\<\

 In the previous example, y'(0) was estimated as being between 0 and 1.0.  \

However, if it were known that y'(0) is between -0.05 and 0.05, then the \

shooting method can be employed.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(shootsoln[d_] := 

      \(NDSolve[{\(\(y'\)'\)[x] - 5\ Sinh[5\ y[x]] == 0, y[0] == 0, 

            \(y'\)[0] == d}, y, {x, 0, 1}]\)[\([1]\)]; \n

    soln = y\  /. \n\t\t

        Module[{s}, \n\t\t\t\t

          FindRoot[

            \((y[1] /. \ \((s = shootsoln[d])\))\) == 1, {d, 

              \(- .05\),  .05}]; s]\)], "Input"],



Cell[BoxData[

    TagBox[\(InterpolatingFunction[{{0.`, 1.`}}, "<>"]\),

      False,

      Editable->False]], "Output"]

}, Open  ]],



Cell[" Note the correct value of y'[0].", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(soln'\)[0]\)], "Input"],



Cell[BoxData[

    \(0.0457417477054563104`\)], "Output"]

}, Open  ]],



Cell["\<\

When the shooting method fails, quasi-linearization can be employed.  The \

non-linear differential equation is linearized about a function and the \

linearized differential equation is solved using the shooting method.  This \

is repeated until the solution has sufficient accuracy.  \

\>", "Text"],



Cell["\<\

The following function linearizes the left-hand side of the differential \

equation by implementing a Taylor series to first order.  The functions and \

the derivatives in the expression are input as vars, and the base functions \

and derivatives about which expr is linearized are input as noms.\

\>", "Text"],



Cell[BoxData[

    \(lin[expr_, vars_, noms_] := 

      Module[{r = Thread[vars -> noms]}, 

          \((expr\  /. \ r)\) + 

            \((vars - noms)\) . 

              \((\((\(D[expr, #]&\)\ /@\ vars)\)\  /. \ r)\)] // Simplify\)], 

  "Input"],



Cell[BoxData[

    \(\(Troesch = \(\(y'\)'\)[x] - 5  Sinh[5  y[x]]; \)\)], "Input"],



Cell[CellGroupData[{



Cell[BoxData[

    \(linTroesch[ys_] = 

      lin[Troesch, {y[x], \(\(y'\)'\)[x]}, {ys[x], \(\(ys'\)'\)[x]}]\)], 

  "Input"],



Cell[BoxData[

    RowBox[{

    \(\(-5\)\ Sinh[5\ ys[x]]\), "+", 

      \(25\ Cosh[5\ ys[x]]\ \((\(-y[x]\) + ys[x])\)\), "+", 

      RowBox[{

        SuperscriptBox["y", "\[DoublePrime]",

          MultilineFunction->None], "[", "x", "]"}]}]], "Output"]

}, Open  ]],



Cell["\<\

The shooting solution is now a function of the starting function ys and of \

y'(0).\

\>", "Text"],



Cell[BoxData[

    \(Remove[shootsoln]\)], "Input"],



Cell[BoxData[

    \(shootsoln[ys_, d_] := 

      \(NDSolve[{linTroesch[ys] == 0, y[0] == 0, \(y'\)[0] == d}, 

          y, {x, 0, 1}]\)[\([1]\)]\)], "Input"],



Cell["\<\

The function iter improves the solution using the shooting method to solve \

the linearized differential equation.  Note that its input and output are \

anonymous functions.  This allows the evaluation of derivatives.\

\>", "Text"],



Cell[BoxData[

    \(iter[ys_] := \ 

      y\  /. \n\t\t\ 

        \(Module[{s}, 

            FindRoot[

              \((y[1]\  /. \ \((s = shootsoln[ys, d])\))\) == 1, {d, 

                \(ys'\)[0], \(ys'\)[0] +  .001}]; s]\)[\([1]\)]\)], "Input"],



Cell["\<\

 The function #&, which satisfies the initial conditions, is used as the \

starting function.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(l = NestList[iter, #&, 7]; \)\)], "Input"],



Cell[BoxData[

    RowBox[{

    \(FindRoot::"precw"\), \( : \ \), 

      "\<\"The precision of the argument function (\\!\\(\\((\\(y[1]\\) /. \

\\((s$5 = \\(shootsoln[\\(\\*TagBox[\\(InterpolatingFunction[\\(\\({{0.`, \

1.`}}\\), \\\"<>\\\"\\)]\\), False, Rule[Editable, False]], d\\)]\\))\\))\\) \

- 1\\)) is less than WorkingPrecision (\\!\\(16\\)).\"\>"}]], "Message"]

}, Open  ]],



Cell["The following plot shows the convergence", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(Plot[Evaluate[Through[l[x]]], {x, 0, 1}]; \)\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.952381 0.0147151 0.588604 [

[.21429 .00222 -9 -9 ]

[.21429 .00222 9 0 ]

[.40476 .00222 -9 -9 ]

[.40476 .00222 9 0 ]

[.59524 .00222 -9 -9 ]

[.59524 .00222 9 0 ]

[.78571 .00222 -9 -9 ]

[.78571 .00222 9 0 ]

[.97619 .00222 -3 -9 ]

[.97619 .00222 3 0 ]

[.01131 .13244 -18 -4.5 ]

[.01131 .13244 0 4.5 ]

[.01131 .25016 -18 -4.5 ]

[.01131 .25016 0 4.5 ]

[.01131 .36788 -18 -4.5 ]

[.01131 .36788 0 4.5 ]

[.01131 .4856 -18 -4.5 ]

[.01131 .4856 0 4.5 ]

[.01131 .60332 -6 -4.5 ]

[.01131 .60332 0 4.5 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.21429 .01472 m

.21429 .02097 L

s

[(0.2)] .21429 .00222 0 1 Mshowa

.40476 .01472 m

.40476 .02097 L

s

[(0.4)] .40476 .00222 0 1 Mshowa

.59524 .01472 m

.59524 .02097 L

s

[(0.6)] .59524 .00222 0 1 Mshowa

.78571 .01472 m

.78571 .02097 L

s

[(0.8)] .78571 .00222 0 1 Mshowa

.97619 .01472 m

.97619 .02097 L

s

[(1)] .97619 .00222 0 1 Mshowa

.125 Mabswid

.07143 .01472 m

.07143 .01847 L

s

.11905 .01472 m

.11905 .01847 L

s

.16667 .01472 m

.16667 .01847 L

s

.2619 .01472 m

.2619 .01847 L

s

.30952 .01472 m

.30952 .01847 L

s

.35714 .01472 m

.35714 .01847 L

s

.45238 .01472 m

.45238 .01847 L

s

.5 .01472 m

.5 .01847 L

s

.54762 .01472 m

.54762 .01847 L

s

.64286 .01472 m

.64286 .01847 L

s

.69048 .01472 m

.69048 .01847 L

s

.7381 .01472 m

.7381 .01847 L

s

.83333 .01472 m

.83333 .01847 L

s

.88095 .01472 m

.88095 .01847 L

s

.92857 .01472 m

.92857 .01847 L

s

.25 Mabswid

0 .01472 m

1 .01472 L

s

.02381 .13244 m

.03006 .13244 L

s

[(0.2)] .01131 .13244 1 0 Mshowa

.02381 .25016 m

.03006 .25016 L

s

[(0.4)] .01131 .25016 1 0 Mshowa

.02381 .36788 m

.03006 .36788 L

s

[(0.6)] .01131 .36788 1 0 Mshowa

.02381 .4856 m

.03006 .4856 L

s

[(0.8)] .01131 .4856 1 0 Mshowa

.02381 .60332 m

.03006 .60332 L

s

[(1)] .01131 .60332 1 0 Mshowa

.125 Mabswid

.02381 .04415 m

.02756 .04415 L

s

.02381 .07358 m

.02756 .07358 L

s

.02381 .10301 m

.02756 .10301 L

s

.02381 .16187 m

.02756 .16187 L

s

.02381 .1913 m

.02756 .1913 L

s

.02381 .22073 m

.02756 .22073 L

s

.02381 .27959 m

.02756 .27959 L

s

.02381 .30902 m

.02756 .30902 L

s

.02381 .33845 m

.02756 .33845 L

s

.02381 .39731 m

.02756 .39731 L

s

.02381 .42674 m

.02756 .42674 L

s

.02381 .45617 m

.02756 .45617 L

s

.02381 .51503 m

.02756 .51503 L

s

.02381 .54446 m

.02756 .54446 L

s

.02381 .57389 m

.02756 .57389 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

.5 Mabswid

.02381 .01472 m

.06244 .03859 L

.10458 .06463 L

.14415 .08909 L

.18221 .11261 L

.22272 .13765 L

.26171 .16175 L

.30316 .18736 L

.34309 .21204 L

.3815 .23578 L

.42237 .26104 L

.46172 .28536 L

.49955 .30874 L

.53984 .33364 L

.57861 .3576 L

.61984 .38308 L

.65954 .40762 L

.69774 .43123 L

.73838 .45635 L

.77751 .48053 L

.81909 .50623 L

.85916 .53099 L

.89771 .55482 L

.93871 .58016 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .02352 L

.10458 .03354 L

.14415 .04372 L

.18221 .0545 L

.22272 .0673 L

.26171 .08107 L

.30316 .09737 L

.34309 .11468 L

.3815 .13275 L

.42237 .15336 L

.46172 .17437 L

.49955 .19546 L

.53984 .21868 L

.57861 .24158 L

.61984 .26635 L

.65954 .29048 L

.69774 .31386 L

.73838 .33887 L

.77751 .36306 L

.81909 .38901 L

.85916 .41476 L

.89771 .44241 L

.91765 .46038 L

.92782 .47181 L

.93871 .48708 L

.94885 .50574 L

.9581 .52865 L

.96739 .56052 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .01815 L

.10458 .02205 L

.14415 .02605 L

.18221 .03033 L

.22272 .03556 L

.26171 .04142 L

.30316 .04874 L

.34309 .05707 L

.3815 .06644 L

.42237 .07803 L

.46172 .09088 L

.49955 .10486 L

.53984 .1215 L

.57861 .13916 L

.61984 .15959 L

.65954 .18075 L

.69774 .20237 L

.73838 .22675 L

.77751 .25184 L

.81909 .28129 L

.85916 .31517 L

.89771 .35963 L

.91765 .39216 L

.92782 .41302 L

.93871 .43998 L

.94885 .47081 L

.9581 .50556 L

.96739 .54946 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .01619 L

.10458 .01786 L

.14415 .01957 L

.18221 .02141 L

.22272 .02367 L

.26171 .02622 L

.30316 .02946 L

.34309 .03322 L

.3815 .03758 L

.42237 .0432 L

.46172 .04975 L

.49955 .05732 L

.53984 .067 L

.57861 .07815 L

.61984 .09232 L

.65954 .1086 L

.69774 .12714 L

.73838 .15068 L

.77751 .17813 L

.81909 .21452 L

.85916 .26046 L

.89771 .32177 L

.91765 .36452 L

.93871 .42333 L

.94807 .45617 L

.9581 .49819 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .01583 L

.10458 .01709 L

.14415 .01838 L

.18221 .01978 L

.22272 .02148 L

.26171 .02342 L

.30316 .02587 L

.34309 .02874 L

.3815 .03208 L

.42237 .03642 L

.46172 .04155 L

.49955 .04757 L

.53984 .05542 L

.57861 .06473 L

.61984 .07697 L

.65954 .09163 L

.69774 .10907 L

.73838 .13226 L

.77751 .16048 L

.81909 .19913 L

.85916 .24863 L

.89771 .31422 L

.91765 .35923 L

.93871 .42025 L

.94807 .45398 L

.9581 .49685 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .01582 L

.10458 .01707 L

.14415 .01835 L

.18221 .01973 L

.22272 .02142 L

.26171 .02333 L

.30316 .02577 L

.34309 .02861 L

.3815 .03192 L

.42237 .03622 L

.46172 .0413 L

.49955 .04727 L

.53984 .05506 L

.57861 .06431 L

.61984 .07648 L

.65954 .09107 L

.69774 .10847 L

.73838 .13163 L

.77751 .15987 L

.81909 .1986 L

.85916 .24821 L

.89771 .31396 L

.91765 .35904 L

.93871 .42015 L

.94807 .4539 L

.9581 .4968 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .01582 L

.10458 .01707 L

.14415 .01835 L

.18221 .01973 L

.22272 .02142 L

.26171 .02333 L

.30316 .02577 L

.34309 .02861 L

.3815 .03192 L

.42237 .03622 L

.46172 .0413 L

.49955 .04727 L

.53984 .05506 L

.57861 .06431 L

.61984 .07648 L

.65954 .09107 L

.69774 .10847 L

.73838 .13163 L

.77751 .15987 L

.81909 .1986 L

.85916 .24821 L

.89771 .31396 L

.91765 .35904 L

.93871 .42015 L

.94807 .4539 L

.9581 .4968 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .01582 L

.10458 .01707 L

.14415 .01835 L

.18221 .01973 L

.22272 .02142 L

.26171 .02333 L

.30316 .02577 L

.34309 .02861 L

.3815 .03192 L

.42237 .03622 L

.46172 .0413 L

.49955 .04727 L

.53984 .05506 L

.57861 .06431 L

.61984 .07648 L

.65954 .09107 L

.69774 .10847 L

.73838 .13163 L

.77751 .15987 L

.81909 .1986 L

.85916 .24821 L

.89771 .31396 L

.91765 .35904 L

.93871 .42015 L

.94807 .4539 L

.9581 .4968 L

.97619 .60332 L

s

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{62, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo0013Ool0

0`00Oomoo`02Ool01000Oomoogoo0`00:7oo00<007ooOol00Woo00<007ooOol00Woo0`009goo00<0

07ooOol00Woo00@007ooOomoo`8002Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Uo

o`D000Ioo`00@Woo00<007oo00001goo00<007ooOol09goo00<007oo00002Goo00<007ooOol09Goo

00<007oo00001goo00<007oo00009goo00<007oo00001goo00<007oo0000;7oo00<007ooOol01Woo

0012Ool00`00Ool00008Ool00`00Oomoo`0VOol00`00Ool00007Ool4000VOol00`00Ool00007Ool0

0`00Ool0000WOol00`00Ool00007Ool00`00Ool0000/Ool00`00Oomoo`06Ool0049oo`03001oo`00

00Qoo`03001oogoo02Ioo`03001oo`0000Moo`03001oo`0002Moo`03001oo`0000Moo`8002Qoo`03

001oo`0000Qoo`03001oogoo02]oo`03001oogoo00Ioo`00@Woo00<007oo00001goo00<007oo0000

9goo00<007oo000027oo0P009goo00<007oo00001goo00<007ooOol09goo00<007oo00001goo00<0

07oo0000;7oo00<007ooOol01Woo0013Ool00`00Oomoo`07Ool00`00Oomoo`0WOol00`00Oomoo`08

Ool00`00Oomoo`0VOol00`00Oomoo`07Ool2000XOol00`00Oomoo`07Ool00`00Oomoo`0ZOol20008

Ool00?moob5oo`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001o

ogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo000?Oooo000A0001Ool001Eooc4000=oo`03001o

ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o

ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o

ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o

ogoo00Yoo`03001oogoo00Eoo`005Goo00<007ooOol00P000goo100017oo30002Woo8@008Goo00<0

07ooOol0<7oo00<007ooOol0<Goo00<007ooOol0<Goo00<007ooOol01Goo000EOol00`00Oomoo`02

Ool00`00Oomoo`04Ool4000<Ool:000FOolF002iOol001Eoo`03001oogoo00=oo`8000Qoo`@0019o

o`P001UooaD00:moo`005Goo00<007ooOol01Goo0P002Woo10005Woo1P007Woo5@00Y7oo000EOol0

0`00Oomoo`07Ool00`00Oomoo`0;Ool4000HOol8000POol80003Ool;002IOol001Eoo`03001oogoo

00Qoo`8000moo`@001aoo`P0021oo`H000Qoo`P0095oo`005Goo0P002goo00<007ooOol047oo0`00

8Goo1P0087oo200027oo1@00S7oo000EOol00`00Oomoo`0;Ool2000COol3000TOol5000SOol70006

Ool50027Ool001Eoo`03001oogoo00eoo`03001oogoo01=oo`@002Eoo`H002Aoo`<000Qoo`H0085o

o`005Goo00<007ooOol03Woo0P005goo0`00:7oo10008goo10002Woo1@00O7oo000EOol00`00Oomo

o`0@Ool00`00Oomoo`0GOol4000XOol3000TOol4000:Ool7001fOol001Eoo`03001oogoo015oo`80

01]oo`@002Moo`@002Aoo`H000Qoo`L0079oo`005Goo00<007ooOol04goo00<007ooOol077oo0`00

:7oo0`009goo100027oo1P00Kgoo000EOol00`00Oomoo`0DOol2000OOol3000XOol4000WOol40007

Ool5001]Ool001Eoo`8001Moo`80021oo`8002Yoo`@002Moo`@000Moo`@006Yoo`005Goo00<007oo

Ool067oo0P0087oo0`00:goo0`00:7oo0`0027oo0`00Igoo000EOol00`00Oomoo`0JOol2000QOol3

000[Ool3000XOol30008Ool3001TOol001Eoo`03001oogoo01aoo`80029oo`<002]oo`8002Uoo`80

00Uoo`80069oo`005Goo00<007ooOol07Woo00<007ooOol08Woo0P00:goo0`00:7oo0`0027oo0`00

Ggoo000EOol00`00Oomoo`0OOol2000TOol3000[Ool3000XOol30008Ool3001LOol001Eoo`03001o

ogoo025oo`03001oogoo02Aoo`<002]oo`<002Qoo`<000Moo`<005Yoo`005Goo00<007ooOol08Woo

00<007ooOol09Woo0P00;7oo10009goo0P001goo1000Egoo000EOol2000TOol2000XOol2000^Ool3

000VOol30006Ool4001EOol001Eoo`03001oogoo02Eoo`03001oogoo02Moo`8002moo`8002Moo`80

00Ioo`@005=oo`005Goo00<007ooOol09Woo0P00:Goo0P00;goo0P009goo0P001Woo1000DGoo000E

Ool00`00Oomoo`0XOol00`00Oomoo`0XOol2000_Ool2000WOol20006Ool3001@Ool001Eoo`03001o

ogoo02Uoo`8002Yoo`8002moo`8002Moo`03001oogoo00Eoo`<004ioo`005Goo00<007ooOol0:goo

0P00:Woo0P00;goo0`009Goo0P001goo0`00C7oo0005Ool00`00Oomoo`02Ool01000Oomoogoo0`00

17oo00<007ooOol0;Goo0P00:Woo0P00<7oo0P009Goo0P001goo0P00Bgoo0004Ool00`00Ool00007

Ool00`00Oomoo`04Ool00`00Oomoo`0_Ool2000ZOol2000`Ool2000UOol00`00Oomoo`06Ool20019

Ool000Aoo`03001oo`0000Qoo`03001oogoo00=oo`<0035oo`8002Yoo`80031oo`8002Aoo`8000Qo

o`03001oogoo04Ioo`0017oo00<007oo000027oo00<007ooOol00goo00<007ooOol0<goo00<007oo

Ool0:Goo0P00<7oo0P0097oo0P001goo0P00AWoo0004Ool00`00Ool00007Ool00`00Ool00004Ool0

0`00Oomoo`0dOol2000[Ool2000`Ool3000SOol20007Ool00`00Oomoo`13Ool000Eoo`03001oogoo

00Moo`03001oogoo00=oo`03001oogoo03Ioo`03001oogoo02Yoo`80035oo`8002=oo`8000Ioo`80

04=oo`005Goo00<007ooOol0=goo0P00;7oo0P00<Goo0P008goo0P001Goo0`00@Goo000EOol00`00

Oomoo`0iOol2000/Ool2000aOol2000SOol00`00Oomoo`04Ool20010Ool001Eoo`03001oogoo03]o

o`03001oogoo02]oo`80035oo`80029oo`8000Eoo`<003ioo`005Goo00<007ooOol0?7oo0P00;Goo

0P00<Goo0P008Woo00<007ooOol00goo0`00?Goo000EOol2000oOol00`00Oomoo`0/Ool2000aOol2

000QOol20005Ool2000lOol001Eoo`03001oogoo03moo`8002ioo`80035oo`80025oo`8000Aoo`80

03]oo`005Goo00<007ooOol0@Goo00<007ooOol0;Goo0P00<Goo0P008Goo00<007ooOol00Woo0P00

>Woo000EOol00`00Oomoo`12Ool2000_Ool2000aOol2000POol20003Ool2000iOol001Eoo`03001o

ogoo04Aoo`8002moo`80035oo`80021oo`04001oogooOol2000hOol001Eoo`03001oogoo04Ioo`03

001oogoo02ioo`80035oo`03001oogoo01ioo`04001oogooOol2000gOol001Eoo`03001oogoo04Mo

o`80031oo`03001oogoo02moo`8001moo`03001oogoo009oo`03001oogoo03Aoo`005Goo00<007oo

Ool0BGoo00<007ooOol0;Woo0P00<Goo0P007Woo00<007ooOol00Woo00<007ooOol0<goo000EOol2

001;Ool2000`Ool2000aOol00`00Oomoo`0LOol00`00Oomoo`02Ool00`00Oomoo`0bOol001Eoo`03

001oogoo04aoo`03001oogoo02moo`03001oogoo02moo`8001eoo`8000=oo`03001oogoo035oo`00

5Goo00<007ooOol0CGoo0P00<7oo0P00<Goo0P007Goo00D007ooOomoo`00039oo`005Goo00<007oo

Ool0Cgoo0P00<7oo0P00<Goo00<007ooOol06goo00D007ooOomoo`00035oo`005Goo00<007ooOol0

DGoo00<007ooOol0;goo0P00<7oo0P0077oo00D007ooOomoo`00031oo`005Goo00<007ooOol0DWoo

0P00<Goo0P00<7oo00<007ooOol06Woo00<007ooOol00P00;goo000EOol00`00Oomoo`1DOol00`00

Oomoo`0`Ool2000_Ool2000KOol01000Oomoo`00;goo000EOol00`00Oomoo`1EOol2000bOol00`00

Oomoo`0^Ool2000JOol01000Oomoo`00;Woo000EOol2001HOol2000aOol2000`Ool00`00Oomoo`0H

Ool01000Oomoo`00;Goo000EOol00`00Oomoo`1IOol00`00Oomoo`0`Ool00`00Oomoo`0^Ool2000I

Ool01000Oomoo`00;7oo000EOol00`00Oomoo`1JOol2000aOol2000`Ool00`00Oomoo`0FOol00`00

Oomoo`02000[Ool001Eoo`03001oogoo05aoo`80035oo`8002moo`8001Moo`03001oogoo008002Yo

o`005Goo00<007ooOol0GWoo00<007ooOol0<7oo00<007ooOol0;Woo0P005Woo00@007ooOol002Yo

o`005Goo00<007ooOol0Ggoo0P00<Goo0P00<7oo0P005Goo00@007ooOol002Uoo`001Goo00<007oo

Ool00Woo00<007ooOol00Woo0`000goo00<007ooOol0HGoo00<007ooOol0<7oo00<007ooOol0;goo

0P0057oo00@007oo000002Qoo`0017oo00<007oo00002Goo00<007ooOol00Woo00<007ooOol0HWoo

0P00<Goo0P00<Goo0P004goo00@007oo000002Moo`0017oo00<007oo00001goo10000goo0`00I7oo

0P00<Goo0P00<Goo00<007ooOol047oo00<007ooOol00P009Woo0004Ool00`00Ool00007Ool00`00

Ool00004Ool00`00Oomoo`1VOol00`00Oomoo`0`Ool2000`Ool2000AOol01000Oomoo`009Woo0004

Ool00`00Ool00008Ool20004Ool00`00Oomoo`1WOol2000bOol2000`Ool00`00Oomoo`0?Ool01000

Ool000009Goo0005Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`1YOol00`00Oomoo`0a

Ool2000_Ool00`00Oomoo`0?Ool00`00Ool0000UOol001Eoo`03001oogoo06Yoo`8003=oo`03001o

ogoo02eoo`80011oo`03001oo`0002Aoo`005Goo00<007ooOol0K7oo00<007ooOol0<Goo0P00;goo

00<007ooOol03Goo00@007oo000002=oo`005Goo00<007ooOol0KGoo0P00<goo00<007ooOol0;Goo

00<007ooOol03Goo00<007oo00008goo000EOol00`00Oomoo`1_Ool2000bOol2000^Ool2000>Ool0

0`00Ool0000ROol001Eoo`80079oo`03001oogoo035oo`8002ioo`03001oogoo00]oo`04001oo`00

000QOol001Eoo`03001oogoo079oo`8003=oo`03001oogoo02aoo`03001oogoo00]oo`03001oo`00

025oo`005Goo00<007ooOol0M7oo00<007ooOol0<Goo0P00;Goo00<007ooOol02goo0`0087oo000E

Ool00`00Oomoo`1eOol2000cOol00`00Oomoo`0[Ool00`00Oomoo`0;Ool2000POol001Eoo`03001o

ogoo07Moo`80039oo`8002aoo`03001oogoo00Yoo`03001oo`0001moo`005Goo00<007ooOol0NGoo

00<007ooOol0<Goo0P00:goo0P002goo0`007Woo000EOol00`00Oomoo`1jOol2000cOol00`00Oomo

o`0ZOol00`00Oomoo`09Ool2000NOol001Eoo`03001oogoo07aoo`80039oo`8002]oo`03001oogoo

00Qoo`03001oo`0001eoo`005Goo0P00Ogoo00<007ooOol0<Goo0P00:Woo00<007ooOol027oo0P00

7Goo000EOol00`00Oomoo`1oOol2000cOol00`00Oomoo`0XOol00`00Oomoo`08Ool2000LOol001Eo

o`03001oogoo085oo`03001oogoo035oo`8002Uoo`03001oogoo00Moo`8001aoo`005Goo00<007oo

Ool0PWoo0P00<goo00<007ooOol09goo00<007ooOol01goo0P006goo000EOol00`00Oomoo`24Ool2

000bOol2000XOol00`00Oomoo`06Ool2000KOol001Eoo`03001oogoo08Ioo`03001oogoo035oo`80

02Moo`03001oogoo00Ioo`8001Yoo`005Goo00<007ooOol0Qgoo0P00<goo00<007ooOol09Goo00<0

07ooOol01Goo0P006Woo000EOol00`00Oomoo`29Ool00`00Oomoo`0aOol2000VOol00`00Oomoo`05

Ool00`00Oomoo`0HOol001Eoo`8008]oo`8003=oo`03001oogoo02Aoo`03001oogoo00Aoo`8001Uo

o`005Goo00<007ooOol0S7oo0P00<Woo0P0097oo00<007ooOol01Goo00<007ooOol05goo000EOol0

0`00Oomoo`2>Ool2000bOol00`00Oomoo`0ROol00`00Oomoo`04Ool00`00Oomoo`0GOol001Eoo`03

001oogoo091oo`80035oo`8002=oo`03001oogoo00=oo`8001Qoo`005Goo00<007ooOol0TWoo0P00

<Goo0P008Woo00<007ooOol00goo00<007ooOol05Woo000EOol00`00Oomoo`2DOol00`00Oomoo`0`

Ool00`00Oomoo`0POol00`00Oomoo`02Ool2000GOol000Eoo`03001oogoo009oo`04001oogooOol2

0005Ool00`00Oomoo`2EOol2000aOol2000QOol00`00Oomoo`02Ool00`00Oomoo`0EOol000Aoo`03

001oo`0000Moo`03001oo`0000Aoo`03001oogoo09Moo`03001oogoo031oo`03001oogoo01moo`05

001oogooOol0000GOol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`<009Qoo`80035oo`8001mo

o`04001oogooOol2000FOol000Aoo`03001oo`0000Moo`8000Eoo`03001oogoo09Yoo`80035oo`03

001oogoo01eoo`05001oogooOol0000FOol000Aoo`03001oo`0000Moo`03001oogoo00Aoo`03001o

ogoo09aoo`03001oogoo02moo`8001eoo`04001oogooOol2000EOol000Eoo`03001oogoo00Moo`80

00Aoo`03001oogoo09eoo`80035oo`8001aoo`05001oogooOol0000EOol001Eoo`03001oogoo09mo

o`03001oogoo031oo`03001oogoo01Uoo`05001oogooOol0000EOol001Eoo`03001oogoo0:1oo`80

035oo`8001Yoo`03001oogoo008001Aoo`005Goo00<007ooOol0XWoo00<007ooOol0<7oo00<007oo

Ool05goo00D007ooOomoo`0001Aoo`005Goo00<007ooOol0Xgoo0P00<Goo0P0067oo00@007ooOol0

01Aoo`005Goo0P00YWoo0P00<Goo00<007ooOol05Woo00@007oo000001=oo`005Goo00<007ooOol0

Ygoo00<007ooOol0;goo0P005Woo00@007ooOol001=oo`005Goo00<007ooOol0Z7oo0P00<Goo0P00

5Goo00@007oo0000019oo`005Goo00<007ooOol0ZWoo00<007ooOol0<7oo00<007ooOol04Woo00@0

07ooOol0019oo`005Goo00<007ooOol0Zgoo0P00<Goo0P004goo00<007oo00004Woo000EOol00`00

Oomoo`2]Ool2000aOol00`00Oomoo`0@Ool01000Ool000004Goo000EOol00`00Oomoo`2_Ool00`00

Oomoo`0_Ool2000AOol00`00Ool0000AOol001Eoo`03001oogoo0;1oo`80035oo`03001oogoo00io

o`03001oo`00015oo`005Goo0P00/goo0P00<7oo0P003goo0P004Goo000EOol00`00Oomoo`2dOol0

0`00Oomoo`0_Ool2000=Ool3000@Ool001Eoo`03001oogoo0;Eoo`80035oo`03001oogoo00Yoo`03

001oo`00011oo`005Goo00<007ooOol0]goo00<007ooOol0;goo0P002goo0P0047oo000EOol00`00

Oomoo`2hOol2000aOol00`00Oomoo`08Ool2000@Ool001Eoo`03001oogoo0;Yoo`80031oo`03001o

ogoo00Moo`<000moo`005Goo00<007ooOol0_7oo00<007ooOol0;Woo00<007ooOol01goo0P003goo

000EOol00`00Oomoo`2mOol2000_Ool00`00Oomoo`06Ool2000?Ool001Eoo`800<1oo`03001oogoo

02eoo`03001oogoo00Ioo`03001oogoo00eoo`005Goo00<007ooOol0`7oo0P00;Woo00<007ooOol0

1Goo0P003Woo000EOol00`00Oomoo`32Ool00`00Oomoo`0/Ool00`00Oomoo`04Ool2000>Ool001Eo

o`03001oogoo0<=oo`8002eoo`03001oogoo00Aoo`03001oogoo00aoo`005Goo00<007ooOol0aGoo

0P00;7oo00<007ooOol00goo00<007ooOol037oo000EOol00`00Oomoo`37Ool00`00Oomoo`0ZOol0

0`00Oomoo`02Ool2000=Ool000Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03

001oogoo0<Qoo`8002]oo`04001oogooOol2000=Ool000Aoo`03001oo`0000Moo`03001oo`0000Ao

o`03001oogoo0<Yoo`03001oogoo02Qoo`03001oogoo009oo`03001oogoo00]oo`0017oo00<007oo

00001goo00<007oo000017oo0`00bgoo0P00:Goo00D007ooOomoo`0000eoo`0017oo00<007oo0000

27oo00<007ooOol00goo00<007ooOol0cGoo00<007ooOol09goo00<007ooOol00P0037oo0004Ool0

0`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`3>Ool2000WOol00`00Oomoo`02000<Ool000Eo

o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo0=1oo`8002Ioo`04001oogoo000<Ool001Eo

o`03001oogoo0=9oo`03001oogoo02=oo`04001oogoo000<Ool001Eoo`03001oogoo0==oo`8002Ao

o`03001oo`0000aoo`005Goo00<007ooOol0eGoo00<007ooOol08Goo00@007oo000000]oo`005Goo

00<007ooOol0eWoo0P008Woo00<007oo00002goo000EOol2003IOol2000POol00`00Ool0000;Ool0

01Eoo`03001oogoo0=Yoo`8001ioo`03001oo`0000]oo`005Goo00<007ooOol0g7oo0P0077oo00<0

07oo00002goo000EOol00`00Oomoo`3NOol2000KOol3000:Ool001Eoo`03001oogoo0>1oo`03001o

ogoo01Qoo`03001oo`0000Yoo`005Goo00<007ooOol0hGoo0P0067oo00<007oo00002Woo000EOol0

0`00Oomoo`3SOol00`00Oomoo`0FOol2000:Ool001Eoo`03001oogoo0>Aoo`8001Ioo`<000Uoo`00

5Goo0P00igoo0P005Goo0P002Goo000EOol00`00Oomoo`3XOol00`00Oomoo`0BOol20009Ool001Eo

o`03001oogoo0>Uoo`80019oo`8000Uoo`005Goo00<007ooOol0jgoo00<007ooOol047oo00<007oo

Ool01goo000EOol00`00Oomoo`3/Ool2000@Ool00`00Oomoo`07Ool001Eoo`03001oogoo0>ioo`03

001oogoo00eoo`8000Qoo`005Goo00<007ooOol0kgoo0P003Goo0P0027oo000EOol00`00Oomoo`3a

Ool2000;Ool20008Ool001Eoo`800?Aoo`03001oogoo00Uoo`03001oogoo00Ioo`005Goo00<007oo

Ool0m7oo0P002Goo00<007ooOol01Woo000EOol00`00Oomoo`3fOol00`00Oomoo`06Ool00`00Oomo

o`06Ool001Eoo`03001oogoo0?Moo`8000Ioo`03001oogoo00Ioo`005Goo00<007ooOol0nGoo0P00

17oo00<007ooOol01Woo000EOol00`00Oomoo`3kOol01000Oomoogoo0P001goo000=Ool50003Ool0

0`00Oomoo`3lOol20002Ool00`00Oomoo`05Ool000moo`03001oogoo00=oo`03001oogoo0?ioo`<0

00Moo`003goo00<007ooOol00goo0`00ogoo0Goo00<007ooOol01Goo000?Ool00`00Oomoo`03Ool0

0`00Oomoo`3oOol9Ool000moo`03001oogoo00=oo`03001oogoo0?moo`Uoo`003Woo0P001Goo00<0

07ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool00001\

\>"],

  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.0829852, -0.07747, 

  0.00386179, 0.00624851}}]

}, Open  ]],



Cell[" All of the solutions satisfy the boundary conditions.", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(Through[l[0]]\)], "Input"],



Cell[BoxData[

    \({0, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}\)], "Output"]

}, Open  ]],



Cell[CellGroupData[{



Cell[BoxData[

    \(Through[l[1]]\)], "Input"],



Cell[BoxData[

    \({1, 1.00000007104394206`, 1.0000002762894653`, 0.999999602623826433`, 

      0.999999998710901927`, 1.00000000095507668`, 1.00000000105766995`, 

      1.00000000000047473`}\)], "Output"]

}, Open  ]],



Cell["\<\

 The value of y'(0) converges to the value found earlier by the shooting \

method\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(Table[\(l[\([i]\)]'\)[0], {i, 8}]\)], "Input"],



Cell[BoxData[

    \({1, 0.366247382272880717`, 0.142707771394194775`, 

      0.0611177735848927561`, 0.0461836674109300204`, 0.045741786300313505`, 

      0.0457417477113576964`, 0.0457417476926261112`}\)], "Output"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{



Cell[" P-N Junction Transport Equations", "Subtitle",

  TextAlignment->Center,

  FontSlant->"Italic"],



Cell["\<\

The equations describing the electron and hole transport in a p-n junction \

cannot be solved by the shooting method, but can be solved with \

quasi-linearization.\

\>", "Text"],



Cell[TextData[{

  " The two following equations give the electron density n as a function of \

potential v and the electron quasi-Fermi level \[Phi]n and the hole density p \

as a function of the potential and the hole quasi-Fermi level \[Phi]p.  ni is \

the intrinsic carrier density, \[Beta] = ",

  Cell[BoxData[

      \(TraditionalForm\`1\/\(k\ T\)\)]],

  " where k is Boltzmann's constant and T is the absolute temperature.  "

}], "Text"],



Cell[BoxData[

    \(n[v_, \[Phi]n_] = ni*Exp[\[Beta] \((v - \[Phi]n)\)]; \n

    p[v_, \[Phi]p_] = ni*Exp[\[Beta] \((\[Phi]p - v)\)]; \)], "Input"],



Cell["\<\

 The total charge density chgDens[x] is equal to the dopant charge density \

dp[x] + the electron and hole charge densities.\

\>", "Text"],



Cell[BoxData[

    \(\(chgDens[x_] = dp[x] - n[v[x], \[Phi]n[x]] + p[v[x], \[Phi]p[x]]; 

    \)\)], "Input"],



Cell["\<\

The following 5 terms are equal to 0 when the differential equations are \

satisfied.  jn and jp are the electron and hole current densities, \

respectively.  The first two equations give the relationship between the \

current densities and the quasi-Fermi levels.  The third equation is \

Poisson's equation.  The fourth and fifth equations reflect the fact that the \

current densities are independent of x in steady-state.\

\>", "Text"],



Cell[BoxData[

    \(eq1 = \(\[Phi]n'\)[x] + jn[x]\/\(q\ \[Mu]n\ n[v[x], \[Phi]n[x]]\); \n

    eq2 = \(\[Phi]p'\)[x] + jp[x]\/\(q\ \[Mu]p\ p[v[x], \[Phi]p[x]]\); \n

    eq3 = \ \(\(v'\)'\)[x] + \(q\/\[Epsilon]\) chgDens[x]; \n

    eq4 = \(jn'\)[x]; \neq5 = \(jp'\)[x]; \)], "Input"],



Cell[" eqs is a list of the five equation left-hand sides.", "Text"],



Cell[BoxData[

    \(\(eqs = {eq1, eq2, eq3, eq4, eq5}; \)\)], "Input"],



Cell["\<\

 The linearized differential equations are functions of the starting \

functions, whose names end in s.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(delin[vs_, \[Phi]ns_, \[Phi]ps_, jns_, jps_] = 

      lin[eqs, {v[x], \(v'\)[x], \(\(v'\)'\)[x], \[Phi]n[x], \(\[Phi]n'\)[x], 

            \[Phi]p[x], \(\[Phi]p'\)[x], jn[x], jp[x]}, {vs[x], \(vs'\)[x], 

            \(\(vs'\)'\)[x], \[Phi]ns[x], \(\[Phi]ns'\)[x], \[Phi]ps[x], 

            \(\[Phi]ps'\)[x], jns[x], jps[x]}] // FullSimplify\)], "Input"],



Cell[BoxData[

    RowBox[{"{", 

      RowBox[{

        FractionBox[

          RowBox[{

          \(E\^\(\[Beta]\ \((\(-vs[x]\) + \[Phi]ns[x])\)\)\ 

              \((jn[x] + 

                  \[Beta]\ jns[x]\ 

                    \((\(-v[x]\) + vs[x] + \[Phi]n[x] - \[Phi]ns[x])\))\)\), 

            "+", 

            RowBox[{"ni", " ", "q", " ", "\[Mu]n", " ", 

              RowBox[{

                SuperscriptBox["\[Phi]n", "\[Prime]",

                  MultilineFunction->None], "[", "x", "]"}]}]}], 

          \(ni\ q\ \[Mu]n\)], ",", 

        FractionBox[

          RowBox[{

          \(E\^\(\[Beta]\ \((vs[x] - \[Phi]ps[x])\)\)\ 

              \((jp[x] + 

                  \[Beta]\ jps[x]\ 

                    \((v[x] - vs[x] - \[Phi]p[x] + \[Phi]ps[x])\))\)\), "+", 

            RowBox[{"ni", " ", "q", " ", "\[Mu]p", " ", 

              RowBox[{

                SuperscriptBox["\[Phi]p", "\[Prime]",

                  MultilineFunction->None], "[", "x", "]"}]}]}], 

          \(ni\ q\ \[Mu]p\)], ",", 

        RowBox[{\(1\/\[Epsilon]\), 

          RowBox[{"(", 

            RowBox[{

            \(\((\(-E\^\(\[Beta]\ \((vs[x] - \[Phi]ns[x])\)\)\) + 

                    E\^\(\[Beta]\ \((\(-vs[x]\) + \[Phi]ps[x])\)\))\)\ ni\ q

                \), "+", \(q\ dp[x]\), "+", 

              \(ni\ q\ \[Beta]\ 

                \((E\^\(\[Beta]\ \((vs[x] - \[Phi]ns[x])\)\)\ 

                      \((\(-v[x]\) + vs[x] + \[Phi]n[x] - \[Phi]ns[x])\) + 

                    E\^\(\[Beta]\ \((\(-vs[x]\) + \[Phi]ps[x])\)\)\ 

                      \((\(-v[x]\) + vs[x] + \[Phi]p[x] - \[Phi]ps[x])\))

                  \)\), "+", 

              RowBox[{"\[Epsilon]", " ", 

                RowBox[{

                  SuperscriptBox["v", "\[DoublePrime]",

                    MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 

        ",", 

        RowBox[{

          SuperscriptBox["jn", "\[Prime]",

            MultilineFunction->None], "[", "x", "]"}], ",", 

        RowBox[{

          SuperscriptBox["jp", "\[Prime]",

            MultilineFunction->None], "[", "x", "]"}]}], "}"}]], "Output"]

}, Open  ]],



Cell[TextData[

"  The following are the initial conditions for the linearized equations.  e0 \

is the electric field as x = 0.  The quasi-Fermi levels are equal to each \

other and to \[Phi]0 at the left boundary."], "Text"],



Cell[BoxData[

    \(\(\ \(ics = {v[0] == v0, \[Phi]n[0] == \[Phi]0, \[Phi]p[0] == \[Phi]0, 

        \(-\(v'\)[0]\) == e0, jn[0] == jn0, jp[0] == jp0}; \)\)\)], "Input"],



Cell[" The following are values of various constants", "Text"],



Cell[BoxData[

    \(\(q = 1.6\ 10\^\(-19\)\ ; 

    \  (*\ the\ charge\ on\ an\ electron\ in\ Coulombs\ *) \n

    k = 1.38\ 10\^\(-23\); \  (*\ Boltzmann' s\ constant\ *) \nt = 300\ ; 

    \  (*\ the\ temperature\ in\ degrees\ Kelvin\ *) \n\[Beta] = q\/\(k\ t\); 

    \n\[Mu]n = 1500; \  (*\ the\ electron\ mobility\ *) \n\[Mu]p = 450; 

    \  (*\ the\ hole\ mobility\ *) \nni = 1.45\ 10\^10; 

    \  (*\ the\ intrinsic\ carrier\ density\ *) \n

    \[Epsilon] = 11.9*8.85\ 10\^\(-14\); 

    \  (*\ the\ permitivity\ of\ silicon\ *) \nl = 10\^\(-4\); 

    \  (*\ the\ total\ thickness\ of\ the\ junction\ *) \)\)], "Input"],



Cell[TextData[{

  " The charge density from the dopants is -dop for ",

  Cell[BoxData[

      \(TraditionalForm\`\(0 < x < l\/2\ \)\)]],

  "and dop for ",

  Cell[BoxData[

      \(TraditionalForm\`l\/2 < x < \ x\)]],

  ".  Therefore the junction is a p-n junction since the negatively charged \

acceptors are between 0 and ",

  Cell[BoxData[

      \(TraditionalForm\`l\/2\)]],

  " and the positively charged donors are between ",

  Cell[BoxData[

      \(TraditionalForm\`l\/2\)]],

  " and l.  "

}], "Text"],



Cell[BoxData[

    \(\(\(dp[x_] = dop*Sign[x - l\/2]; \) (*\ the\ dopant\ profile\ *) \)\)], 

  "Input"],



Cell["\<\

The following are the electric potential across the junction and the dopant \

concentration.\

\>", "Text"],



Cell[BoxData[

    \(\(dop = 10\^15; \  (*\ the\ dopant\ concentration\ *) \nv0 = 0.0; 

    \  (*\ the\ potential\ at\ the\ left\ boundary\ *) \nv1 = 0.45; 

    \  (*\ the\ potential\ at\ the\ right\ boundary\ *) \)\)], "Input"],



Cell["\<\

 The built-in potential can be calculated from the concentration of dopants.  \

The fact that the potential difference across the junction is less than the \

built-in potential indicates that the junction is forward biased.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(\ vbi = \(\[Beta]\^\(-1\)\) Log[dop\^2\/ni\^2]\)\)], "Input"],



Cell[BoxData[

    \(0.576565478766828309`\)], "Output"]

}, Open  ]],



Cell["\<\

 At the boundaries, the quasi-Fermi levels are equal and the total charge \

density dp - n + p is 0.  This enables calculation of the values of the \

quasi-Fermi levels at the boundaries.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\[Phi]0 = 

      \[Phi]0\  /. \ 

        \(FindRoot[

            dp[0] - n[v0, \[Phi]0] + p[v0, \[Phi]0] == 0, {\[Phi]0,  .3}]\)[

          \([1]\)]\)], "Input"],



Cell[BoxData[

    \(0.28828273938885438`\)], "Output"]

}, Open  ]],



Cell[CellGroupData[{



Cell[BoxData[

    \(\[Phi]1\  = \ 

      \[Phi]1\  /. \ 

        \(FindRoot[

            dp[1] - n[v1, \[Phi]1] + p[v1, \[Phi]1] == 0, {\[Phi]1,  .3}]\)[

          \([1]\)]\)], "Input"],



Cell[BoxData[

    \(0.161717260611145574`\)], "Output"]

}, Open  ]],



Cell[TextData[

" The following function linsoln gives the solution to the linearized \

equation as a function of the starting functions vs, \[Phi]ns, \[Phi]ps, jns \

and jps, and as a function of the initial conditions e0, jn0 and jp0.  "], 

  "Text"],



Cell[BoxData[

    \(linsoln[vs_, \[Phi]ns_, \[Phi]ps_, jns_, jps_, e0_, jn0_, jp0_] := \n\t

      \(NDSolve[\n\t\t

          Thread[delin[vs, \[Phi]ns, \[Phi]ps, jns, jps] == 0]~Join~ics, {v, 

            \[Phi]n, \[Phi]p, jn, jp}, {x, 0, l}, Compiled -> False, 

          InterpolationPrecision -> 5]\)[\([1]\)]\)], "Input"],



Cell["\<\

  The function iter calculates improved functions for the potential, the \

electron and hole quasi-Fermi levels, and the electron and hole current \

densities, using linsoln.  The starting values for the required initial \

conditions are calculated from the functions.\

\>", "Text"],



Cell[BoxData[

    \(iter[{vs_, \[Phi]ns_, \[Phi]ps_, jns_, jps_}] := 

      \t{v, \[Phi]n, \[Phi]p, jn, jp}\  /. \n\t

        Module[{s}, \t\ \n\t\t\t

          FindRoot[\n

            \(({v[l], \[Phi]n[l], \[Phi]p[l]}\  /. 

                  \((s = \ 

                      linsoln[vs, \[Phi]ns, \[Phi]ps, jns, jps, e0, jn0, jp0])

                    \))\)\t == \n\t\t\t\t{v1, \[Phi]1, \[Phi]1}, {e0, 

              \(-\  .95\)\ \(vs'\)[0], \(-1.05\)\ \(vs'\)[0]}, {

              jn0,  .95\ \ jns[0], 1.05  jns[0]}, {jp0,  .95\ jps[0], 

              1.05\ jps[0]}, MaxIterations -> 6]; s]\)], "Input"],



Cell["\<\

 The initial potential and quasi-Fermi level functions are assumed to be \

linear.  The initial current density functions are assumed to be constant.\

\>", "Text"],



Cell[BoxData[

    \(\(i0 = {\((v0 + \(\(v1 - v0\)\/l\) #)\)&, 

        \((\[Phi]0 + \(\(\[Phi]1 - \[Phi]0\)\/l\) #)\)\ &, 

        \((\[Phi]0 + \(\(\[Phi]1 - \[Phi]0\)\/l\) #)\)\ &, 10\^\(-7\)&, 

        10\^\(-7\)\ &}; \)\)], "Input"],



Cell["\<\

The function iter is applied 7 times.  The number of MaxIterations for \

FindRoot was limited because it is the repeated application of iter which \

improves the solution.  Therefore precision warning messages are generated.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(iterations = NestList[iter, i0, 7]; \)\)], "Input"],



Cell[BoxData[

    \(FindRoot::"frsec" \( : \ \) 

      "Secant method failed to converge to the prescribed accuracy after \

\!\(6\) iterations."\)], "Message"],



Cell[BoxData[

    RowBox[{

    \(FindRoot::"precw"\), \( : \ \), 

      "\<\"The precision of the argument function (\\!\\(\\((\\({\\(v[l]\\), \

\\(\\\\[Phi]n[l]\\), \\(\\\\[Phi]p[l]\\)}\\) /. \\((s$802 = \

\\(linsoln[\\(\\*TagBox[\\(\\\\[LeftSkeleton] 1 \\\\[RightSkeleton]\\), \

False, Rule[Editable, False]], \\(\\\\[LeftSkeleton] 1 \

\\\\[RightSkeleton]\\), \\*TagBox[\\(\\\\[LeftSkeleton] 1 \\\\[RightSkeleton]\

\\), False, Rule[Editable, False]], \\*TagBox[\\(\\(\\\\[LeftSkeleton] 21 \

\\\\[RightSkeleton]\\)[\\(\\\\[LeftSkeleton] 1 \\\\[RightSkeleton]\\)]\\), \

False, Rule[Editable, False]], \\(\\\\[LeftSkeleton] 1 \

\\\\[RightSkeleton]\\), e0, jn0, jp0\\)]\\))\\))\\) - \\(\\\\[LeftSkeleton] 1 \

\\\\[RightSkeleton]\\)\\)) is less than WorkingPrecision \

(\\!\\(16\\)).\"\>"}]], "Message"]

}, Open  ]],



Cell["The following plot shows the convergence of  v[x] .", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(Plot[

      Evaluate[Table[\(iterations[\([nn, 1]\)]\)[x], {nn, 7}]], {x, 0, l}, 

      Ticks -> {{{5\ 10\^\(-5\), \*"\"\<5. \!\(10\^\(-5\)\)\>\""}, {

              10\^\(-4\), \*"\"\<1. \!\(10\^\(-4\)\)\>\""}}, Automatic}]; 

    \)\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 9523.81 0.0147151 1.308 [

[.5 .00222 -21.375 -13.1875 ]

[.5 .00222 21.375 0 ]

[.97619 .00222 -21.375 -13.1875 ]

[.97619 .00222 21.375 0 ]

[.01131 .14552 -18 -4.5 ]

[.01131 .14552 0 4.5 ]

[.01131 .27632 -18 -4.5 ]

[.01131 .27632 0 4.5 ]

[.01131 .40711 -18 -4.5 ]

[.01131 .40711 0 4.5 ]

[.01131 .53791 -18 -4.5 ]

[.01131 .53791 0 4.5 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.5 .01472 m

.5 .02097 L

s

gsave

.5 .00222 -82.375 -17.1875 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 21.1875 translate 1 -1 scale

gsave

0.000000 0.000000 0.000000 setrgbcolor

1.000000 setlinewidth

gsave

newpath

 61.000000 17.187500 moveto

 464.000000 17.187500 lineto

 464.000000 4.000000 lineto

 61.000000 4.000000 lineto

 61.000000 17.187500 lineto

closepath

clip newpath

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(5.) show

81.000000 13.437500 moveto

(10) show

93.000000 9.187500 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

97.187500 9.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(5) show

101.750000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

grestore

grestore

%%DocumentNeededResources: font Math1Mono

%%+ font Courier

%%DocumentSuppliedResources:

%%DocumentNeededFonts: Math1Mono

%%+ Courier

%%DocumentSuppliedFonts:

%%DocumentFonts: font Math1Mono

%%+ font Courier

grestore

.97619 .01472 m

.97619 .02097 L

s

gsave

.97619 .00222 -82.375 -17.1875 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 21.1875 translate 1 -1 scale

gsave

0.000000 0.000000 0.000000 setrgbcolor

1.000000 setlinewidth

gsave

newpath

 61.000000 17.187500 moveto

 464.000000 17.187500 lineto

 464.000000 4.000000 lineto

 61.000000 4.000000 lineto

 61.000000 17.187500 lineto

closepath

clip newpath

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.) show

81.000000 13.437500 moveto

(10) show

93.000000 9.187500 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

97.187500 9.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(4) show

101.750000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

grestore

grestore

%%DocumentNeededResources: font Math1Mono

%%+ font Courier

%%DocumentSuppliedResources:

%%DocumentNeededFonts: Math1Mono

%%+ Courier

%%DocumentSuppliedFonts:

%%DocumentFonts: font Math1Mono

%%+ font Courier

grestore

0 .01472 m

1 .01472 L

s

.02381 .14552 m

.03006 .14552 L

s

[(0.1)] .01131 .14552 1 0 Mshowa

.02381 .27632 m

.03006 .27632 L

s

[(0.2)] .01131 .27632 1 0 Mshowa

.02381 .40711 m

.03006 .40711 L

s

[(0.3)] .01131 .40711 1 0 Mshowa

.02381 .53791 m

.03006 .53791 L

s

[(0.4)] .01131 .53791 1 0 Mshowa

.125 Mabswid

.02381 .04088 m

.02756 .04088 L

s

.02381 .06704 m

.02756 .06704 L

s

.02381 .0932 m

.02756 .0932 L

s

.02381 .11936 m

.02756 .11936 L

s

.02381 .17168 m

.02756 .17168 L

s

.02381 .19784 m

.02756 .19784 L

s

.02381 .224 m

.02756 .224 L

s

.02381 .25016 m

.02756 .25016 L

s

.02381 .30248 m

.02756 .30248 L

s

.02381 .32864 m

.02756 .32864 L

s

.02381 .3548 m

.02756 .3548 L

s

.02381 .38095 m

.02756 .38095 L

s

.02381 .43327 m

.02756 .43327 L

s

.02381 .45943 m

.02756 .45943 L

s

.02381 .48559 m

.02756 .48559 L

s

.02381 .51175 m

.02756 .51175 L

s

.02381 .56407 m

.02756 .56407 L

s

.02381 .59023 m

.02756 .59023 L

s

.02381 .61639 m

.02756 .61639 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

.5 Mabswid

.02381 .01472 m

.06244 .03859 L

.10458 .06463 L

.14415 .08909 L

.18221 .11261 L

.22272 .13765 L

.26171 .16174 L

.30316 .18736 L

.34309 .21204 L

.3815 .23578 L

.42237 .26103 L

.46172 .28535 L

.49955 .30874 L

.53984 .33364 L

.57861 .3576 L

.61984 .38308 L

.65954 .40762 L

.69774 .43122 L

.73838 .45634 L

.77751 .48053 L

.81909 .50622 L

.85916 .53099 L

.89771 .55481 L

.93871 .58015 L

.97619 .60331 L

s

.02381 .01472 m

.06244 .02391 L

.10458 .03521 L

.14415 .04809 L

.18221 .06314 L

.22272 .08235 L

.26171 .10412 L

.30316 .13085 L

.34309 .16013 L

.3815 .1916 L

.42237 .22861 L

.46172 .26772 L

.49955 .30851 L

.53984 .35192 L

.57861 .39034 L

.61984 .42758 L

.65954 .45993 L

.69774 .4878 L

.73838 .51397 L

.77751 .53579 L

.81909 .55545 L

.85916 .57112 L

.89771 .58349 L

.93871 .59441 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .0255 L

.10458 .03829 L

.14415 .05205 L

.18221 .06744 L

.22272 .08658 L

.26171 .10798 L

.30316 .13415 L

.34309 .1628 L

.3815 .19363 L

.42237 .22995 L

.46172 .26838 L

.49955 .30852 L

.53984 .35124 L

.57861 .38899 L

.61984 .42552 L

.65954 .45722 L

.69774 .48448 L

.73838 .5101 L

.77751 .53157 L

.81909 .55116 L

.85916 .56721 L

.89771 .58048 L

.93871 .59286 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .02552 L

.10458 .03832 L

.14415 .05209 L

.18221 .06749 L

.22272 .08662 L

.26171 .10802 L

.30316 .13418 L

.34309 .16283 L

.3815 .19365 L

.42237 .22996 L

.46172 .26838 L

.49955 .30852 L

.53984 .35123 L

.57861 .38898 L

.61984 .4255 L

.65954 .45719 L

.69774 .48445 L

.73838 .51006 L

.77751 .53152 L

.81909 .55111 L

.85916 .56717 L

.89771 .58045 L

.93871 .59285 L

.97619 .60331 L

s

.02381 .01472 m

.06244 .02552 L

.10458 .03832 L

.14415 .05209 L

.18221 .06749 L

.22272 .08662 L

.26171 .10802 L

.30316 .13418 L

.34309 .16283 L

.3815 .19365 L

.42237 .22996 L

.46172 .26838 L

.49955 .30852 L

.53984 .35123 L

.57861 .38897 L

.61984 .4255 L

.65954 .45719 L

.69774 .48445 L

.73838 .51006 L

.77751 .53152 L

.81909 .55111 L

.85916 .56717 L

.89771 .58045 L

.93871 .59285 L

.97619 .60332 L

s

.02381 .01472 m

.06244 .02552 L

.10458 .03832 L

.14415 .05209 L

.18221 .06749 L

.22272 .08662 L

.26171 .10802 L

.30316 .13418 L

.34309 .16283 L

.3815 .19365 L

.42237 .22996 L

.46172 .26838 L

.49955 .30852 L

.53984 .35123 L

.57861 .38897 L

.61984 .4255 L

.65954 .45719 L

.69774 .48445 L

.73838 .51006 L

.77751 .53152 L

.81909 .55111 L

.85916 .56717 L

.89771 .58045 L

.93871 .59285 L

.97619 .60331 L

s

.02381 .01472 m

.06244 .02552 L

.10458 .03832 L

.14415 .05209 L

.18221 .06749 L

.22272 .08662 L

.26171 .10802 L

.30316 .13418 L

.34309 .16283 L

.3815 .19365 L

.42237 .22997 L

.46172 .26838 L

.49955 .30852 L

.53984 .35123 L

.57861 .38898 L

.61984 .4255 L

.65954 .45719 L

.69774 .48445 L

.73838 .51006 L

.77751 .53152 L

.81909 .55111 L

.85916 .56717 L

.89771 .58045 L

.93871 .59285 L

.97619 .60332 L

s

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{62, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ

Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001nOol00`00Oomoo`02Ool0

0`00Oomoo`08Ool50002Ool00`00Oomoo`1NOol50002Ool00`00Oomoo`08Ool50002Ool00`00Oomo

o`0>Ool007eoo`03001oo`00011oo`07001oogooOol007oo0000HGoo00<007ooOol03goo00L007oo

Oomoo`00Ool0000?Ool007moo`03001oogoo00ioo`07001oogooOol007oo0000HGoo00<007ooOol0

3goo00L007ooOomoo`00Ool0000?Ool007eoo`80015oo`07001oogooOol007oo0000HGoo00<007oo

Ool03goo00L007ooOomoo`00Ool0000?Ool007eoo`03001oogoo011oo`07001oogooOol007oo0000

27oo0`00EWoo00<007ooOol03goo00L007ooOomoo`00Ool00009Ool20004Ool007eoo`<000moo`80

00Aoo`03001oogoo00=oo`<000=oo`03001oogoo05=oo`80011oo`8000Aoo`03001oogoo00=oo`<0

0004Ool000000004Ool00:5oo`03001oogoo07Eoo`03001oo`0000Aoo`00Wgoo0P00NGoo00<007oo

Ool00goo000EOol00`00Oomoo`27Ool3001hOol00`00Oomoo`03Ool001Eoo`03001oogoo0?moo`Uo

o`005Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool000moool00080011oo`005Goo

2000LWoo00<007ooOol0Mgoo00<007ooOol057oo000EOol00`00Oomoo`09003oOol001Eoo`03001o

ogoo009oo`04001oogooOol6003lOol001Eoo`03001oogoo00=oo`8000Aoo`L00?Qoo`005Goo00<0

07ooOol01Goo0P001Goo1`00mGoo000EOol00`00Oomoo`07Ool00`00Oomoo`06Ool7003aOol001Eo

o`8000Uoo`8000Uoo`P00>eoo`005Goo00<007ooOol02Woo00<007ooOol02Woo1`00jWoo000EOol0

0`00Oomoo`0;Ool00`00Oomoo`0=Ool5003XOol001Eoo`03001oogoo00aoo`80011oo`@00>Ioo`00

5Goo00<007ooOol03Woo00<007ooOol03goo1000i7oo000EOol00`00Oomoo`0?Ool2000AOol5003Q

Ool001Eoo`80019oo`03001oogoo011oo`D00=moo`005Goo00<007ooOol04Woo0P004goo1000gGoo

000EOol00`00Oomoo`0DOol2000COol4003KOol001Eoo`03001oogoo01Ioo`8001=oo`@00=Uoo`00

5Goo00<007ooOol067oo0P004goo1000egoo000EOol00`00Oomoo`0JOol2000COol4003EOol001Eo

o`03001oogoo01aoo`03001oogoo019oo`@00==oo`005Goo0P007Woo0P0057oo0`00dWoo000EOol0

0`00Oomoo`0OOol00`00Oomoo`0COol3003@Ool001Eoo`03001oogoo021oo`8001Aoo`@00<ioo`00

5Goo00<007ooOol08Woo00<007ooOol04goo0`00cGoo000EOol00`00Oomoo`0SOol2000EOol3003;

Ool001Eoo`03001oogoo02Eoo`03001oogoo01=oo`<00<Yoo`005Goo00<007ooOol09Woo0P005Goo

0P00bGoo000EOol2000YOol2000EOol20037Ool001Eoo`03001oogoo02Yoo`8001Aoo`800<Ioo`00

5Goo00<007ooOol0;7oo0P0057oo0P00a7oo000EOol00`00Oomoo`0^Ool2000DOol00`00Oomoo`31

Ool000Eoo`03001oogoo009oo`03001oogoo00D000=oo`03001oogoo031oo`03001oogoo019oo`80

0<5oo`0017oo00<007oo000027oo00<007ooOol00goo00<007ooOol0<Goo0P0057oo00<007ooOol0

_Woo0004Ool00`00Ool00008Ool00`00Oomoo`03Ool2000dOol00`00Oomoo`0BOol2002nOol000Ao

o`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo03Aoo`03001oogoo019oo`<00;aoo`0017oo

00<007oo000027oo00<007ooOol00goo00<007ooOol0=Goo0P0057oo0P00^goo0005Ool00`00Oomo

o`06Ool20005Ool00`00Oomoo`0gOol00`00Oomoo`0BOol3002iOol001Eoo`03001oogoo03Qoo`80

01=oo`<00;Qoo`005Goo00<007ooOol0>Woo00<007ooOol04Woo0P00]goo000EOol00`00Oomoo`0k

Ool2000COol3002eOol001Eoo`8003ioo`80019oo`<00;Aoo`005Goo00<007ooOol0?goo00<007oo

Ool04Goo0P00/goo000EOol00`00Oomoo`10Ool2000BOol2002bOol001Eoo`03001oogoo049oo`80

015oo`<00;1oo`005Goo00<007ooOol0A7oo00<007ooOol03goo0`00[goo000EOol00`00Oomoo`15

Ool2000AOol2002^Ool001Eoo`03001oogoo04Moo`80011oo`800:eoo`005Goo0P00BWoo0P003goo

0P00[7oo000EOol00`00Oomoo`1;Ool2000>Ool2002[Ool001Eoo`03001oogoo04eoo`8000eoo`80

0:Yoo`005Goo00<007ooOol0Cgoo00<007ooOol02goo0P00ZGoo000EOol00`00Oomoo`1@Ool2000<

Ool2002XOol001Eoo`03001oogoo059oo`03001oogoo00]oo`03001oogoo0:Eoo`005Goo00<007oo

Ool0Dgoo00<007ooOol02goo00<007ooOol0Y7oo000EOol2001EOol2000<Ool00`00Oomoo`2SOol0

01Eoo`03001oogoo05Ioo`03001oogoo00Yoo`03001oogoo0:9oo`005Goo00<007ooOol0Egoo0P00

2goo00<007ooOol0XGoo000EOol00`00Oomoo`1IOol00`00Oomoo`09Ool00`00Oomoo`2POol001Eo

o`03001oogoo05Yoo`8000Yoo`03001oogoo09moo`005Goo00<007ooOol0G7oo0P002Goo00<007oo

Ool0WWoo000EOol2001OOol00`00Oomoo`07Ool00`00Oomoo`2MOol001Eoo`03001oogoo05moo`80

00Qoo`03001oogoo09aoo`005Goo00<007ooOol0HGoo0P001goo00<007ooOol0Vgoo000EOol00`00

Oomoo`1SOol00`00Oomoo`05Ool00`00Oomoo`2JOol001Eoo`03001oogoo06Aoo`8000Ioo`03001o

ogoo09Uoo`001Goo00<007ooOol00Woo00@007ooOomoo`<000Aoo`03001oogoo06Ioo`8000Eoo`03

001oogoo09Qoo`0017oo00<007oo00001goo00<007ooOol017oo00<007ooOol0J7oo00<007ooOol0

0goo00<007ooOol0Ugoo0004Ool00`00Ool00008Ool00`00Oomoo`03Ool2001ZOol20004Ool00`00

Oomoo`2FOol000Aoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo06]oo`8000=oo`03001o

ogoo09Eoo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol0KGoo00D007ooOomoo`00

09Ioo`001Goo00<007ooOol01goo00<007ooOol00goo00<007ooOol0KWoo0P000Woo00<007ooOol0

Tgoo000EOol00`00Oomoo`1`Ool200000goo001oo`2COol001Eoo`03001oogoo079oo`03001oo`00

09=oo`005Goo00<007ooOol0Lgoo0`00TWoo000EOol2001fOol2002AOol001Eoo`03001oogoo07Mo

o`03001oogoo08ioo`005Goo00<007ooOol0N7oo0P00SWoo000EOol00`00Oomoo`1iOol2002=Ool0

01Eoo`03001oogoo07Yoo`8008aoo`005Goo00<007ooOol0Ngoo0`00RWoo000EOol2001mOol00`00

Ool00029Ool001Eoo`03001oogoo07aoo`03001oogoo008008Moo`005Goo00<007ooOol0OGoo00D0

07ooOomoo`0008Ioo`005Goo00<007ooOol0OWoo00@007ooOomoo`8008Aoo`005Goo00<007ooOol0

Ogoo00<007ooOol00Woo0P00PWoo000EOol00`00Oomoo`20Ool00`00Oomoo`03Ool00`00Oomoo`1o

Ool001Eoo`03001oogoo085oo`03001oogoo00=oo`8007moo`005Goo0P00Pgoo00<007ooOol017oo

0P00OGoo000EOol00`00Oomoo`23Ool00`00Oomoo`05Ool00`00Oomoo`1jOol001Eoo`03001oogoo

08Aoo`03001oogoo00Eoo`8007Yoo`005Goo00<007ooOol0QGoo00<007ooOol01Woo0P00N7oo000E

Ool00`00Oomoo`26Ool00`00Oomoo`07Ool2001fOol001Eoo`03001oogoo08Moo`03001oogoo00Qo

o`8007Aoo`005Goo00<007ooOol0R7oo00<007ooOol02Goo0P00LWoo000EOol2002:Ool00`00Oomo

o`0:Ool00`00Oomoo`1_Ool001Eoo`03001oogoo08Yoo`03001oogoo00Yoo`8006moo`005Goo00<0

07ooOol0Rgoo00<007ooOol02goo00<007ooOol0K7oo000EOol00`00Oomoo`2<Ool00`00Oomoo`0;

Ool00`00Oomoo`1[Ool001Eoo`03001oogoo08eoo`8000aoo`8006]oo`001Goo00<007ooOol00Woo

00@007ooOomoo`8000Eoo`03001oogoo08ioo`8000eoo`03001oogoo06Qoo`0017oo00<007oo0000

2Goo00<007ooOol00Woo00<007ooOol0Sgoo0P003Goo0P00J7oo0004Ool00`00Ool00008Ool00`00

Oomoo`03Ool2002AOol2000>Ool00`00Oomoo`1UOol000Aoo`03001oo`0000Uoo`03001oogoo009o

o`03001oogoo099oo`03001oogoo00aoo`8006Eoo`0017oo00<007oo00001goo00<007oo000017oo

00<007ooOol0Tgoo0P003Woo0P00Hgoo0005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo

o`2DOol2000?Ool00`00Oomoo`1POol001Eoo`03001oogoo09Eoo`8000moo`80061oo`005Goo00<0

07ooOol0UWoo0P0047oo0P00GWoo000EOol2002HOol3000@Ool00`00Oomoo`1KOol001Eoo`03001o

ogoo09Qoo`<0011oo`8005]oo`005Goo00<007ooOol0VWoo0P004Goo0P00FGoo000EOol00`00Oomo

o`2KOol2000BOol00`00Oomoo`1FOol001Eoo`03001oogoo09aoo`<0015oo`8005Ioo`005Goo00<0

07ooOol0WGoo0`004Woo0P00E7oo000EOol00`00Oomoo`2OOol2000COol00`00Oomoo`1AOol001Eo

o`800:5oo`<0019oo`80055oo`005Goo00<007ooOol0XGoo0`004goo0P00Cgoo000EOol00`00Oomo

o`2SOol2000DOol00`00Oomoo`1<Ool001Eoo`03001oogoo0:Aoo`<001=oo`8004aoo`005Goo00<0

07ooOol0YGoo0`0057oo0P00BWoo000EOol00`00Oomoo`2WOol3000DOol00`00Oomoo`17Ool001Eo

o`03001oogoo0:Qoo`<001Aoo`8004Moo`005Goo0P00Zgoo0`0057oo00<007ooOol0A7oo000EOol0

0`00Oomoo`2[Ool3000DOol20014Ool001Eoo`03001oogoo0:eoo`8001Eoo`80049oo`005Goo00<0

07ooOol0[Woo0`005Goo00<007ooOol0?goo000EOol00`00Oomoo`2_Ool3000EOol2000oOol001Eo

o`03001oogoo0;5oo`<001Eoo`03001oogoo03aoo`005Goo0P00/goo0`005Goo0P00?7oo000EOol0

0`00Oomoo`2dOol3000EOol2000jOol001Eoo`03001oogoo0;Eoo`@001Eoo`03001oogoo03Moo`00

5Goo00<007ooOol0]goo100057oo0P00=goo000EOol00`00Oomoo`2iOol01000Ool0000057oo0P00

=Goo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`2jOol2000017oo0000

00004goo00<007ooOol0<Woo0004Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`2lOol2

0002Ool2000BOol2000bOol000Aoo`03001oo`0000Moo`@000=oo`800;moo`80009oo`80019oo`80

031oo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol0`7oo0P000Woo0P004Woo00<0

07ooOol0;Goo0004Ool00`00Ool00008Ool20004Ool00`00Oomoo`32Ool20002Ool2000AOol2000]

Ool000Eoo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo0<Aoo`80009oo`80015oo`8002]o

o`005Goo00<007ooOol0aWoo0P000Woo0P004Goo00<007ooOol0:7oo000EOol00`00Oomoo`38Ool3

00000goo0000000@Ool2000XOol001Eoo`03001oogoo0<]oo`800003Ool00000011oo`03001oogoo

02Eoo`005Goo0P00cWoo1@003goo0P009Goo000EOol00`00Oomoo`3@Ool5000>Ool2000SOol001Eo

o`03001oogoo0=9oo`H000eoo`03001oogoo021oo`005Goo00<007ooOol0eGoo1`002Woo0P0087oo

000EOol00`00Oomoo`3HOol70009Ool00`00Oomoo`0MOol001Eoo`03001oogoo0=aoo`L000Ioo`80

01eoo`005Goo00<007ooOol0ggoo200017oo00<007ooOol06Woo000EOol2003TOol70002Ool2000J

Ool001Eoo`03001oogoo0>Moo`H00003Ool007oo01Qoo`005Goo00<007ooOol0jgoo1P005goo000E

Ool00`00Oomoo`3_Ool3000FOol001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo2Goo

000EOol2003oOol:Ool001Eoo`03001oogoo0?moo`Uoo`00ogoo8Goo003oOolQOol00001\

\>"],

  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.67748*^-06, -0.0573458, 

  4.0914*^-07, 0.00297903}}]

}, Open  ]],



Cell[TextData[

"The next plot shows the convergence of \[Phi]n[x]  and \[Phi]p[x] ."], "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(Plot[

      Evaluate[Join[Table[\(iterations[\([nn, 2]\)]\)[x], {nn, 7}], 

          Table[\(iterations[\([nn, 3]\)]\)[x], {nn, 7}]]], {x, 0, l}, 

      PlotRange -> {{0, l}, { .16,  .30}}, 

      Ticks -> {{{5\ 10\^\(-5\), \*"\"\<5. \!\(10\^\(-5\)\)\>\""}, {

              10\^\(-4\), \*"\"\<1. \!\(10\^\(-4\)\)\>\""}}, Automatic}]; 

    \)\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0 10000 -0.706325 4.41453 [

[.5 .16408 -21.375 -13.1875 ]

[.5 .16408 21.375 0 ]

[1 .16408 -21.375 -13.1875 ]

[1 .16408 21.375 0 ]

[-0.0125 0 -24 -4.5 ]

[-0.0125 0 0 4.5 ]

[-0.0125 .08829 -24 -4.5 ]

[-0.0125 .08829 0 4.5 ]

[-0.0125 .26487 -24 -4.5 ]

[-0.0125 .26487 0 4.5 ]

[-0.0125 .35316 -24 -4.5 ]

[-0.0125 .35316 0 4.5 ]

[-0.0125 .44145 -24 -4.5 ]

[-0.0125 .44145 0 4.5 ]

[-0.0125 .52974 -24 -4.5 ]

[-0.0125 .52974 0 4.5 ]

[-0.0125 .61803 -18 -4.5 ]

[-0.0125 .61803 0 4.5 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.5 .17658 m

.5 .18283 L

s

gsave

.5 .16408 -82.375 -17.1875 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 21.1875 translate 1 -1 scale

gsave

0.000000 0.000000 0.000000 setrgbcolor

1.000000 setlinewidth

gsave

newpath

 61.000000 17.187500 moveto

 464.000000 17.187500 lineto

 464.000000 4.000000 lineto

 61.000000 4.000000 lineto

 61.000000 17.187500 lineto

closepath

clip newpath

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(5.) show

81.000000 13.437500 moveto

(10) show

93.000000 9.187500 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

97.187500 9.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(5) show

101.750000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

grestore

grestore

%%DocumentNeededResources: font Math1Mono

%%+ font Courier

%%DocumentSuppliedResources:

%%DocumentNeededFonts: Math1Mono

%%+ Courier

%%DocumentSuppliedFonts:

%%DocumentFonts: font Math1Mono

%%+ font Courier

grestore

1 .17658 m

1 .18283 L

s

gsave

1 .16408 -82.375 -17.1875 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 21.1875 translate 1 -1 scale

gsave

0.000000 0.000000 0.000000 setrgbcolor

1.000000 setlinewidth

gsave

newpath

 61.000000 17.187500 moveto

 464.000000 17.187500 lineto

 464.000000 4.000000 lineto

 61.000000 4.000000 lineto

 61.000000 17.187500 lineto

closepath

clip newpath

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.) show

81.000000 13.437500 moveto

(10) show

93.000000 9.187500 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

97.187500 9.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(4) show

101.750000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

grestore

grestore

%%DocumentNeededResources: font Math1Mono

%%+ font Courier

%%DocumentSuppliedResources:

%%DocumentNeededFonts: Math1Mono

%%+ Courier

%%DocumentSuppliedFonts:

%%DocumentFonts: font Math1Mono

%%+ font Courier

grestore

0 .17658 m

1 .17658 L

s

0 0 m

.00625 0 L

s

[(0.16)] -0.0125 0 1 0 Mshowa

0 .08829 m

.00625 .08829 L

s

[(0.18)] -0.0125 .08829 1 0 Mshowa

0 .26487 m

.00625 .26487 L

s

[(0.22)] -0.0125 .26487 1 0 Mshowa

0 .35316 m

.00625 .35316 L

s

[(0.24)] -0.0125 .35316 1 0 Mshowa

0 .44145 m

.00625 .44145 L

s

[(0.26)] -0.0125 .44145 1 0 Mshowa

0 .52974 m

.00625 .52974 L

s

[(0.28)] -0.0125 .52974 1 0 Mshowa

0 .61803 m

.00625 .61803 L

s

[(0.3)] -0.0125 .61803 1 0 Mshowa

.125 Mabswid

0 .02207 m

.00375 .02207 L

s

0 .04415 m

.00375 .04415 L

s

0 .06622 m

.00375 .06622 L

s

0 .11036 m

.00375 .11036 L

s

0 .13244 m

.00375 .13244 L

s

0 .15451 m

.00375 .15451 L

s

0 .19865 m

.00375 .19865 L

s

0 .22073 m

.00375 .22073 L

s

0 .2428 m

.00375 .2428 L

s

0 .28694 m

.00375 .28694 L

s

0 .30902 m

.00375 .30902 L

s

0 .33109 m

.00375 .33109 L

s

0 .37523 m

.00375 .37523 L

s

0 .39731 m

.00375 .39731 L

s

0 .41938 m

.00375 .41938 L

s

0 .46353 m

.00375 .46353 L

s

0 .4856 m

.00375 .4856 L

s

0 .50767 m

.00375 .50767 L

s

0 .55182 m

.00375 .55182 L

s

0 .57389 m

.00375 .57389 L

s

0 .59596 m

.00375 .59596 L

s

.25 Mabswid

0 0 m

0 .61803 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

.5 Mabswid

0 .56631 m

.04057 .54364 L

.08481 .51892 L

.12636 .49571 L

.16632 .47338 L

.20885 .44962 L

.2498 .42674 L

.29331 .40243 L

.33524 .379 L

.37557 .35646 L

.41848 .33249 L

.4598 .3094 L

.49953 .28721 L

.54183 .26357 L

.58254 .24083 L

.62583 .21664 L

.66752 .19335 L

.70762 .17094 L

.7503 .14709 L

.79139 .12414 L

.83505 .09974 L

.87712 .07624 L

.9176 .05362 L

.96065 .02957 L

1 .00758 L

s

0 .56631 m

.00942 .44991 L

.01975 .35265 L

.03053 .27559 L

.04057 .22034 L

.05176 .17271 L

.06194 .13906 L

.0737 .10889 L

.08481 .0869 L

.09499 .07103 L

.10578 .0577 L

.12514 .04043 L

.13503 .03407 L

.14565 .02859 L

.16487 .0214 L

.17548 .01854 L

.18706 .01609 L

.19812 .01426 L

.20816 .01294 L

.21808 .01189 L

.22881 .01098 L

.24015 .01023 L

.25083 .00967 L

.26166 .00923 L

.27177 .0089 L

.28231 .00862 L

.29389 .00839 L

.30486 .00821 L

.31526 .00808 L

.33474 .0079 L

.34488 .00784 L

.35565 .00778 L

.37499 .00771 L

.38483 .00769 L

.39543 .00766 L

.41463 .00763 L

.42467 .00762 L

.43567 .00761 L

.44714 .00761 L

.45782 .0076 L

.46887 .0076 L

.4793 .00759 L

.49882 .00759 L

.50903 .00759 L

.51983 .00759 L

.53921 .00758 L

.54912 .00758 L

.55976 .00758 L

.56974 .00758 L

.57899 .00758 L

Mistroke

.58963 .00758 L

.60122 .00758 L

.61145 .00758 L

.62233 .00758 L

.63316 .00758 L

.64486 .00758 L

.6559 .00758 L

.66605 .00758 L

.67561 .00758 L

.68585 .00758 L

.69709 .00758 L

.70756 .00758 L

.71827 .00758 L

.72991 .00758 L

.73996 .00758 L

.75105 .00758 L

.76107 .00758 L

.77185 .00758 L

.78324 .00758 L

.79392 .00758 L

.81501 .00758 L

.8256 .00758 L

.83718 .00758 L

.8478 .00758 L

.85781 .00758 L

.86935 .00758 L

.87982 .00758 L

.89005 .00758 L

.90088 .00758 L

.92026 .00758 L

.9302 .00758 L

.94086 .00758 L

.9601 .00758 L

.96991 .00758 L

.98058 .00758 L

1 .00758 L

Mfstroke

0 .5663 m

.00123 .49073 L

.00236 .4368 L

.00357 .39002 L

.00488 .34896 L

.00722 .29314 L

.00942 .25402 L

.01203 .21891 L

.01479 .19044 L

.01975 .1536 L

.02221 .13982 L

.02486 .12735 L

.02966 .10935 L

.03535 .09327 L

.04057 .08198 L

.05141 .06504 L

.05755 .05802 L

.06325 .0526 L

.07435 .04423 L

.08481 .03817 L

.09516 .03338 L

.10636 .02916 L

.12589 .02348 L

.14683 .01904 L

.16895 .01562 L

.18957 .01328 L

.20882 .01166 L

.23019 .01034 L

.24967 .00948 L

.26971 .00885 L

.28103 .00858 L

.29151 .00838 L

.31111 .0081 L

.32227 .00798 L

.33274 .00789 L

.34306 .00782 L

.35393 .00777 L

.36411 .00772 L

.37336 .00769 L

.38338 .00767 L

.39409 .00765 L

.40401 .00763 L

.41338 .00762 L

.42358 .00761 L

.43439 .0076 L

.44362 .0076 L

.45377 .00759 L

.46444 .00759 L

.47418 .00759 L

.48544 .00759 L

Mistroke

.49612 .00758 L

.50621 .00758 L

.51696 .00758 L

.52703 .00758 L

.53628 .00758 L

.54144 .00758 L

.54711 .00758 L

.5528 .00758 L

.5588 .00758 L

.5699 .00758 L

.58 .00758 L

.59054 .00758 L

.60052 .00758 L

.61105 .00758 L

.6225 .00758 L

.63239 .00758 L

.6433 .00758 L

.65469 .00758 L

.66537 .00758 L

.67572 .00758 L

.68661 .00758 L

.70605 .00758 L

.7161 .00758 L

.72682 .00758 L

.74612 .00758 L

.7569 .00758 L

.76857 .00758 L

.78974 .00758 L

.81065 .00758 L

.83276 .00758 L

.85336 .00758 L

.8726 .00758 L

.91342 .00758 L

.9357 .00758 L

.95682 .00758 L

.99703 .00758 L

1 .00758 L

Mfstroke

0 .5663 m

.00123 .43931 L

.00236 .38124 L

.00365 .33871 L

.00488 .31047 L

.00601 .29036 L

.00706 .27518 L

.00942 .24856 L

.01181 .2285 L

.01444 .21113 L

.01975 .18481 L

.02493 .1657 L

.0305 .14933 L

.04057 .12633 L

.05241 .1058 L

.06367 .09037 L

.08481 .06828 L

.1056 .05243 L

.12491 .04131 L

.14646 .0319 L

.166 .02547 L

.18621 .02043 L

.20807 .01641 L

.229 .01363 L

.23968 .01254 L

.25112 .01156 L

.26191 .0108 L

.27174 .01022 L

.29099 .00934 L

.3014 .00899 L

.31103 .00872 L

.32227 .00846 L

.33283 .00827 L

.35243 .00801 L

.36284 .00791 L

.37406 .00783 L

.38411 .00777 L

.3951 .00772 L

.40658 .00769 L

.41726 .00766 L

.4283 .00764 L

.43874 .00762 L

.4481 .00761 L

.45825 .00761 L

.46819 .0076 L

.47912 .00759 L

.49054 .00759 L

.50122 .00759 L

.51214 .00759 L

.52252 .00758 L

Mistroke

.53183 .00758 L

.5371 .00758 L

.54198 .00758 L

.54733 .00758 L

.55311 .00758 L

.56357 .00758 L

.57376 .00758 L

.58312 .00758 L

.59337 .00758 L

.60293 .00758 L

.61341 .00758 L

.62464 .00758 L

.63535 .00758 L

.64698 .00758 L

.65797 .00758 L

.66812 .00758 L

.68776 .00758 L

.69893 .00758 L

.70941 .00758 L

.71976 .00758 L

.73064 .00758 L

.75009 .00758 L

.77086 .00758 L

.79015 .00758 L

.81168 .00758 L

.83121 .00758 L

.85139 .00758 L

.87324 .00758 L

.89374 .00758 L

.91626 .00758 L

.95769 .00758 L

1 .00758 L

Mfstroke

0 .5663 m

.00123 .45809 L

.00236 .40806 L

.00365 .36936 L

.00488 .34221 L

.00706 .30615 L

.00942 .27712 L

.01203 .25226 L

.01479 .23108 L

.01975 .2015 L

.02486 .17814 L

.02966 .16053 L

.04057 .1301 L

.0517 .10759 L

.06188 .09168 L

.07377 .07691 L

.08481 .06585 L

.10474 .05041 L

.1265 .03822 L

.14805 .02946 L

.16759 .02356 L

.1878 .01899 L

.20966 .01538 L

.23059 .01291 L

.24114 .01195 L

.25271 .01107 L

.2732 .00989 L

.28468 .0094 L

.29516 .00903 L

.3152 .00851 L

.32652 .0083 L

.337 .00814 L

.35659 .00793 L

.36775 .00784 L

.37822 .00778 L

.38855 .00773 L

.39942 .0077 L

.4087 .00767 L

.41885 .00765 L

.42964 .00763 L

.43944 .00762 L

.45075 .00761 L

.46144 .0076 L

.47164 .0076 L

.47723 .00759 L

.48245 .00759 L

.49168 .00759 L

.50183 .00759 L

.51275 .00759 L

.52313 .00758 L

Mistroke

.53334 .00758 L

.54259 .00758 L

.54779 .00758 L

.55268 .00758 L

.56343 .00758 L

.57272 .00758 L

.58275 .00758 L

.59275 .00758 L

.60372 .00758 L

.61518 .00758 L

.62586 .00758 L

.63686 .00758 L

.64727 .00758 L

.66676 .00758 L

.67693 .00758 L

.68771 .00758 L

.70707 .00758 L

.71693 .00758 L

.72755 .00758 L

.74676 .00758 L

.76784 .00758 L

.79001 .00758 L

.81078 .00758 L

.83008 .00758 L

.8516 .00758 L

.87113 .00758 L

.89302 .00758 L

.91317 .00758 L

.95361 .00758 L

.99504 .00758 L

1 .00758 L

Mfstroke

0 .5663 m

.00123 .45841 L

.00236 .40827 L

.00365 .36933 L

.00488 .34199 L

.00706 .30572 L

.00942 .27663 L

.01203 .25179 L

.01479 .23069 L

.01975 .20128 L

.02486 .17807 L

.02966 .16057 L

.04057 .13025 L

.0517 .10777 L

.06188 .09184 L

.07377 .07704 L

.08481 .06594 L

.10474 .05047 L

.1265 .03825 L

.14805 .02946 L

.16759 .02356 L

.1878 .01899 L

.20966 .01538 L

.23059 .01291 L

.24114 .01195 L

.25271 .01107 L

.2732 .00989 L

.28468 .0094 L

.29516 .00903 L

.3152 .00851 L

.32652 .0083 L

.337 .00814 L

.35659 .00793 L

.36775 .00784 L

.37822 .00778 L

.38855 .00773 L

.39942 .0077 L

.4087 .00767 L

.41885 .00765 L

.42964 .00763 L

.43944 .00762 L

.45075 .00761 L

.46144 .0076 L

.47164 .0076 L

.47723 .00759 L

.48245 .00759 L

.49168 .00759 L

.50183 .00759 L

.51275 .00759 L

.52313 .00758 L

Mistroke

.53244 .00758 L

.54259 .00758 L

.54819 .00758 L

.55345 .00758 L

.56329 .00758 L

.57388 .00758 L

.58532 .00758 L

.59533 .00758 L

.6063 .00758 L

.61775 .00758 L

.62843 .00758 L

.63943 .00758 L

.64984 .00758 L

.66934 .00758 L

.6795 .00758 L

.69029 .00758 L

.70964 .00758 L

.71951 .00758 L

.73013 .00758 L

.74933 .00758 L

.77042 .00758 L

.79259 .00758 L

.81336 .00758 L

.83265 .00758 L

.85418 .00758 L

.87371 .00758 L

.89559 .00758 L

.91574 .00758 L

.95619 .00758 L

.99761 .00758 L

1 .00758 L

Mfstroke

0 .5663 m

.00123 .45841 L

.00236 .40827 L

.00365 .36933 L

.00488 .34199 L

.00706 .30572 L

.00942 .27663 L

.01203 .25179 L

.01479 .23069 L

.01975 .20128 L

.02486 .17807 L

.02966 .16057 L

.04057 .13025 L

.0517 .10777 L

.06188 .09184 L

.07377 .07704 L

.08481 .06594 L

.10474 .05046 L

.1265 .03825 L

.14805 .02946 L

.16759 .02356 L

.1878 .01899 L

.20966 .01538 L

.23059 .01291 L

.24114 .01195 L

.25271 .01107 L

.2732 .00989 L

.28468 .0094 L

.29516 .00903 L

.3152 .00851 L

.32652 .0083 L

.337 .00814 L

.35659 .00793 L

.36775 .00784 L

.37822 .00778 L

.38855 .00773 L

.39942 .0077 L

.4087 .00767 L

.41885 .00765 L

.42964 .00763 L

.43944 .00762 L

.45075 .00761 L

.46144 .0076 L

.47164 .0076 L

.47723 .00759 L

.48245 .00759 L

.49168 .00759 L

.50183 .00759 L

.51275 .00759 L

.52313 .00758 L

Mistroke

.53244 .00758 L

.54259 .00758 L

.55345 .00758 L

.56329 .00758 L

.56875 .00758 L

.57464 .00758 L

.58532 .00758 L

.59533 .00758 L

.6063 .00758 L

.61775 .00758 L

.62843 .00758 L

.63943 .00758 L

.64984 .00758 L

.66934 .00758 L

.6795 .00758 L

.69029 .00758 L

.70964 .00758 L

.71951 .00758 L

.73013 .00758 L

.74933 .00758 L

.77042 .00758 L

.79259 .00758 L

.81336 .00758 L

.83265 .00758 L

.85418 .00758 L

.87371 .00758 L

.89559 .00758 L

.91574 .00758 L

.95619 .00758 L

.99761 .00758 L

1 .00758 L

Mfstroke

0 .56631 m

.04057 .54364 L

.08481 .51892 L

.12636 .49571 L

.16632 .47338 L

.20885 .44962 L

.2498 .42674 L

.29331 .40243 L

.33524 .379 L

.37557 .35646 L

.41848 .33249 L

.4598 .3094 L

.49953 .28721 L

.54183 .26357 L

.58254 .24083 L

.62583 .21664 L

.66752 .19335 L

.70762 .17094 L

.7503 .14709 L

.79139 .12414 L

.83505 .09974 L

.87712 .07624 L

.9176 .05362 L

.96065 .02957 L

1 .00758 L

s

0 .56631 m

.00942 .56631 L

.01975 .56631 L

.04057 .56631 L

.05163 .56631 L

.06347 .56631 L

.08481 .56631 L

.09554 .56631 L

.10718 .56631 L

.11724 .56631 L

.12833 .56631 L

.14916 .56631 L

.16056 .56631 L

.17124 .56631 L

.18214 .56631 L

.1925 .56631 L

.21195 .56631 L

.22201 .56631 L

.23274 .56631 L

.25205 .56631 L

.26285 .56631 L

.27453 .56631 L

.28556 .56631 L

.29571 .56631 L

.31548 .56631 L

.3267 .56631 L

.33717 .56631 L

.34815 .56631 L

.35854 .56631 L

.37803 .56631 L

.38816 .56631 L

.39893 .56631 L

.40812 .56631 L

.41827 .56631 L

.42887 .56631 L

.43859 .56631 L

.44925 .56631 L

.46049 .56631 L

.47051 .5663 L

.48121 .5663 L

.49132 .5663 L

.5005 .5663 L

.51098 .5663 L

.52064 .5663 L

.53125 .56629 L

.54248 .56629 L

.55239 .56628 L

.56303 .56628 L

.57308 .56627 L

.58226 .56626 L

Mistroke

.60224 .56623 L

.61354 .5662 L

.62401 .56617 L

.63514 .56613 L

.6456 .56609 L

.66515 .56596 L

.67543 .56587 L

.68628 .56575 L

.70569 .56545 L

.71566 .56524 L

.72635 .56496 L

.74561 .56427 L

.75632 .56373 L

.76796 .563 L

.77801 .56221 L

.78909 .56112 L

.8099 .55827 L

.82129 .5561 L

.83197 .55357 L

.84232 .55053 L

.8532 .54656 L

.87265 .53689 L

.8827 .53018 L

.89342 .52132 L

.91272 .49937 L

.9235 .48247 L

.93517 .45886 L

.94619 .4296 L

.95634 .39426 L

.96655 .3471 L

.97608 .2876 L

.98655 .19593 L

.99242 .12641 L

.99777 .04664 L

1 .00758 L

Mfstroke

0 .56631 m

.04057 .56631 L

.06168 .56631 L

.08481 .56631 L

.12636 .56631 L

.14691 .56631 L

.16889 .56631 L

.19126 .56631 L

.21241 .56631 L

.23338 .56631 L

.25275 .56631 L

.27241 .56631 L

.28359 .56631 L

.29406 .56631 L

.30496 .56631 L

.31532 .56631 L

.33477 .56631 L

.34484 .56631 L

.35557 .56631 L

.3657 .56631 L

.37488 .56631 L

.3854 .56631 L

.39509 .56631 L

.40572 .56631 L

.41695 .56631 L

.4269 .56631 L

.43757 .56631 L

.44764 .56631 L

.45682 .56631 L

.46723 .56631 L

.47686 .56631 L

.48743 .56631 L

.49866 .5663 L

.50849 .5663 L

.51366 .5663 L

.5191 .5663 L

.52911 .5663 L

.53829 .5663 L

.54832 .56629 L

.55902 .56629 L

.56913 .56628 L

.57831 .56627 L

.58879 .56626 L

.59845 .56624 L

.60906 .56622 L

.62029 .56619 L

.6302 .56616 L

.64084 .56611 L

.66007 .566 L

.67071 .56591 L

Mistroke

.6823 .56579 L

.69338 .56564 L

.70341 .56547 L

.72411 .565 L

.73546 .56466 L

.74614 .56426 L

.76727 .56323 L

.78668 .56191 L

.80648 .56008 L

.82819 .55734 L

.84872 .55382 L

.87069 .54871 L

.8814 .54556 L

.89304 .54148 L

.90309 .53729 L

.91418 .53173 L

.9242 .52556 L

.93498 .51727 L

.94637 .50569 L

.95191 .49852 L

.95705 .49057 L

.96706 .46974 L

.97235 .45421 L

.97799 .43176 L

.98084 .41691 L

.98393 .39685 L

.98684 .37247 L

.98953 .34301 L

.99195 .30749 L

.99462 .25237 L

.99596 .21432 L

.9974 .16126 L

.99876 .09344 L

1 .00758 L

Mfstroke

0 .56631 m

.04057 .56631 L

.06168 .56631 L

.08481 .56631 L

.12636 .56631 L

.14691 .56631 L

.16889 .56631 L

.19126 .56631 L

.21241 .56631 L

.23338 .56631 L

.25275 .56631 L

.27241 .56631 L

.28359 .56631 L

.29406 .56631 L

.30496 .56631 L

.31532 .56631 L

.33477 .56631 L

.34484 .56631 L

.35557 .56631 L

.36563 .56631 L

.37488 .56631 L

.38568 .56631 L

.39736 .56631 L

.40766 .56631 L

.41854 .56631 L

.42849 .56631 L

.43916 .56631 L

.44923 .56631 L

.45841 .56631 L

.46882 .5663 L

.47845 .5663 L

.48902 .5663 L

.50025 .5663 L

.51009 .5663 L

.51562 .5663 L

.52069 .56629 L

.52997 .56629 L

.53988 .56628 L

.55018 .56628 L

.55975 .56627 L

.57114 .56625 L

.58149 .56623 L

.59197 .5662 L

.60163 .56617 L

.61224 .56613 L

.62347 .56607 L

.63338 .566 L

.64402 .56591 L

.66325 .56568 L

.67389 .5655 L

Mistroke

.68549 .56526 L

.69656 .56496 L

.70659 .56463 L

.72729 .56372 L

.73864 .56305 L

.74933 .56229 L

.77045 .5603 L

.78986 .55777 L

.80966 .55427 L

.83138 .54905 L

.8519 .54239 L

.87388 .53278 L

.89622 .51945 L

.91736 .50218 L

.92752 .49164 L

.93831 .47831 L

.95766 .4462 L

.96753 .42325 L

.9727 .40819 L

.97815 .38886 L

.98294 .36723 L

.98547 .3531 L

.98817 .33482 L

.99067 .31349 L

.99293 .28803 L

.99402 .27242 L

.99521 .25175 L

.99633 .22679 L

.99735 .19622 L

.99861 .13977 L

1 .00759 L

Mfstroke

0 .56631 m

.04057 .56631 L

.06168 .56631 L

.08481 .56631 L

.12636 .56631 L

.14691 .56631 L

.16889 .56631 L

.19126 .56631 L

.21241 .56631 L

.23338 .56631 L

.25275 .56631 L

.27241 .56631 L

.28359 .56631 L

.29406 .56631 L

.30496 .56631 L

.31532 .56631 L

.33477 .56631 L

.34484 .56631 L

.35557 .56631 L

.3657 .56631 L

.37488 .56631 L

.3854 .56631 L

.39509 .56631 L

.40572 .56631 L

.41695 .56631 L

.4269 .56631 L

.43757 .56631 L

.44764 .56631 L

.45682 .56631 L

.46723 .56631 L

.47686 .5663 L

.48743 .5663 L

.49866 .5663 L

.50849 .5663 L

.51366 .5663 L

.5191 .5663 L

.52911 .56629 L

.53829 .56629 L

.54832 .56628 L

.55902 .56627 L

.56913 .56626 L

.57831 .56624 L

.58879 .56622 L

.59845 .5662 L

.60906 .56616 L

.62029 .56611 L

.6302 .56605 L

.64084 .56598 L

.66007 .56578 L

.67071 .56563 L

Mistroke

.6823 .56542 L

.69338 .56517 L

.70341 .56489 L

.72411 .56412 L

.73546 .56355 L

.74614 .56289 L

.76727 .56119 L

.78668 .559 L

.80648 .55596 L

.82819 .5514 L

.84872 .54552 L

.87069 .53696 L

.89304 .5249 L

.90329 .51784 L

.91418 .50897 L

.92414 .49926 L

.93512 .48632 L

.94456 .47268 L

.95448 .45482 L

.9651 .42968 L

.97483 .39756 L

.98026 .37309 L

.98531 .34301 L

.98821 .32051 L

.99084 .29476 L

.9923 .27725 L

.99388 .25437 L

.99537 .22722 L

.99675 .19438 L

.99755 .16944 L

.9983 .13965 L

.99912 .09401 L

1 .00777 L

Mfstroke

0 .56631 m

.04057 .56631 L

.06168 .56631 L

.08481 .56631 L

.12636 .56631 L

.14691 .56631 L

.16889 .56631 L

.19126 .56631 L

.21241 .56631 L

.23338 .56631 L

.25275 .56631 L

.27241 .56631 L

.28359 .56631 L

.29406 .56631 L

.30496 .56631 L

.31532 .56631 L

.33477 .56631 L

.34484 .56631 L

.35557 .56631 L

.3657 .56631 L

.37488 .56631 L

.3854 .56631 L

.39509 .56631 L

.40572 .56631 L

.41695 .56631 L

.4269 .56631 L

.43757 .56631 L

.44764 .56631 L

.45682 .56631 L

.46723 .56631 L

.47686 .5663 L

.48743 .5663 L

.49866 .5663 L

.50849 .5663 L

.51366 .5663 L

.5191 .5663 L

.52911 .56629 L

.53829 .56629 L

.54832 .56628 L

.55902 .56627 L

.56913 .56626 L

.57831 .56624 L

.58879 .56622 L

.59845 .5662 L

.60906 .56616 L

.62029 .56611 L

.6302 .56605 L

.64084 .56598 L

.66007 .56578 L

.67071 .56563 L

Mistroke

.6823 .56542 L

.69338 .56517 L

.70341 .5649 L

.72411 .56412 L

.73546 .56355 L

.74614 .5629 L

.76727 .56119 L

.78668 .559 L

.80648 .55596 L

.82819 .5514 L

.84872 .54552 L

.87069 .53695 L

.89304 .52486 L

.90329 .51778 L

.91418 .50887 L

.92414 .49912 L

.93512 .48611 L

.94456 .4724 L

.95448 .45445 L

.9651 .42922 L

.97483 .39703 L

.98026 .37256 L

.98531 .34252 L

.98821 .32006 L

.99084 .29436 L

.9923 .27686 L

.99388 .254 L

.99537 .22682 L

.99675 .19394 L

.99755 .16898 L

.9983 .13919 L

.99912 .09363 L

1 .00756 L

Mfstroke

0 .56631 m

.04057 .56631 L

.06168 .56631 L

.08481 .56631 L

.12636 .56631 L

.14691 .56631 L

.16889 .56631 L

.19126 .56631 L

.21241 .56631 L

.23338 .56631 L

.25275 .56631 L

.27241 .56631 L

.28359 .56631 L

.29406 .56631 L

.30496 .56631 L

.31532 .56631 L

.33477 .56631 L

.34484 .56631 L

.35557 .56631 L

.3657 .56631 L

.37488 .56631 L

.3854 .56631 L

.39509 .56631 L

.40572 .56631 L

.41695 .56631 L

.4269 .56631 L

.43757 .56631 L

.44764 .56631 L

.45682 .56631 L

.46723 .56631 L

.47686 .5663 L

.48743 .5663 L

.49866 .5663 L

.50849 .5663 L

.5191 .5663 L

.52911 .56629 L

.53829 .56629 L

.54859 .56628 L

.55816 .56627 L

.56867 .56626 L

.5799 .56624 L

.59065 .56622 L

.60231 .56619 L

.61332 .56615 L

.62347 .5661 L

.63365 .56603 L

.64317 .56596 L

.65362 .56586 L

.66484 .56572 L

.67548 .56555 L

Mistroke

.68708 .56533 L

.69815 .56505 L

.70818 .56475 L

.72888 .5639 L

.74024 .56327 L

.75092 .56256 L

.77204 .56072 L

.79145 .55836 L

.81126 .55509 L

.83297 .5502 L

.85349 .5439 L

.87547 .53472 L

.89781 .52174 L

.90807 .5141 L

.91895 .50446 L

.92891 .49386 L

.9399 .47959 L

.94933 .4644 L

.95925 .44419 L

.96415 .43198 L

.9695 .41628 L

.97887 .37971 L

.98417 .35048 L

.98714 .32941 L

.98983 .30563 L

.99234 .27713 L

.99366 .25838 L

.99506 .23423 L

.99629 .20756 L

.99763 .16814 L

.99886 .11383 L

1 .01651 L

Mfstroke

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{62, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ

Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00

ogoo8Goo003oOolQOol00?moob5oo`001Woo00<007ooOol00Woo00<007ooOol01@0000=oo`000000

ogoo2goo0005Ool00`00Ool00008Ool01`00Oomoogoo001oo`000?moo`Yoo`001Goo00<007oo0000

27oo00L007ooOomoo`00Ool00003Ool3003oOol4Ool000Eoo`03001oo`0000Qoo`04001oogooOol2

0004Ool00`00Oomoo`3oOol4Ool000Eoo`03001oo`0000Qoo`05001oogooOol00005Ool00`00Oomo

o`0kOonb000FOol000Ioo`03001oogoo00Ioo`8000Aoo`8000=oo`03001oogoo02Uooa`00:Eoo`<0

01Ioo`006Woo00<007ooOol097oo4P00/Woo0P000Woo00<007ooOol057oo000JOol00`00Oomoo`0O

Ool?002hOol20004Ool00`00Oomoo`0DOol001Yoo`8001]oo`D000=oo`H00;aoo`8000Ioo`03001o

ogoo01Aoo`006Woo00<007ooOol05Woo10001Woo1000_goo00<007ooOol01Woo00<007ooOol057oo

000JOol00`00Oomoo`0DOol20008Ool4002oOol20009Ool00`00Oomoo`0DOol001Yoo`03001oogoo

019oo`8000Qoo`<00<1oo`8000]oo`03001oogoo01Aoo`006Woo00<007ooOol047oo0P0027oo0`00

`7oo0P003Goo00<007ooOol057oo000JOol2000@Ool00`00Oomoo`06Ool30030Ool2000?Ool00`00

Oomoo`0DOol001Yoo`03001oogoo00ioo`03001oogoo00Eoo`@00;moo`80015oo`03001oogoo01Ao

o`006Woo00<007ooOol03Goo00<007ooOol01Goo00@007oo00000;moo`03001oogoo015oo`03001o

ogoo01Aoo`006Woo00<007ooOol02goo0P001goo00@007oo00000;ioo`8001Aoo`03001oogoo01Ao

o`006Woo00<007ooOol02Woo00<007ooOol01Woo1000_Goo0P005Woo00<007ooOol057oo000JOol2

000;Ool00`00Oomoo`05Ool200000goo001oo`2kOol2000GOol2000FOol001Yoo`03001oogoo00Uo

o`03001oogoo00Eoo`800003Ool007oo0;Yoo`8001Uoo`8001Ioo`006Woo00<007ooOol027oo00<0

07ooOol01Goo0P0000=oo`00Ool0^Woo00<007ooOol06Goo0P005Woo0006Ool00`00Oomoo`02Ool0

0`00Oomoo`050002Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`04Ool20002Ool00`00

Oomoo`2gOol2000LOol2000FOol000Eoo`03001oo`0000Qoo`07001oogooOol007oo00000goo00<0

07ooOol01goo00<007ooOol017oo0P000Woo00<007ooOol0]Woo0P007Woo0P005Woo0005Ool00`00

Ool00008Ool01`00Oomoogoo001oo`0000=oo`<000Moo`03001oogoo00=oo`8000=oo`03001oogoo

0;Eoo`03001oogoo01ioo`8001Ioo`001Goo00<007oo000027oo00<007ooOol00Woo00<007ooOol0

0Woo00<007ooOol01Woo00<007ooOol00goo0P000goo00<007ooOol0]7oo0P008Goo0P005Woo0005

Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Ioo`03001oogoo009oo`80

00Aoo`03001oogoo0;9oo`8002=oo`8001Ioo`001Woo00<007ooOol01Woo0P0017oo00<007ooOol0

0Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0/Woo00<007ooOol0

8goo0P005Woo000JOol00`00Oomoo`05Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`2`Ool2000V

Ool2000FOol001Yoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo0:mo

o`8002Moo`03001oo`0001Ioo`006Woo0P001Woo00D007ooOomoo`0000Eoo`03001oogoo0:eoo`80

02Uoo`03001oo`0001Ioo`006Woo00<007ooOol017oo00@007ooOomoo`8000Aoo`03001oogoo0:ao

o`8002]oo`03001oo`0001Ioo`006Woo00<007ooOol017oo00D007ooOomoo`0000Eoo`03001oogoo

0:Yoo`8002eoo`03001oo`0001Ioo`006Woo00<007ooOol00goo00@007ooOomoo`8000Aoo`03001o

ogoo0:Yoo`03001oogoo02eoo`03001oo`0001Ioo`006Woo00<007ooOol00goo00D007ooOomoo`00

00Eoo`03001oogoo05=oo`03001oogoo009oo`03001oogoo00Qoo`D0009oo`03001oogoo03]oo`80

01moo`D0009oo`03001oogoo00Moo`H0009oo`03001oogoo00ioo`006Woo0P0017oo00<007ooOol0

0P0017oo00<007ooOol0Dgoo00<007oo000047oo00L007ooOomoo`00Ool0000jOol2000SOol00`00

Oomoo`0<Ool01000Ool000000goo00<007oo00003goo000JOol00`00Oomoo`03Ool01000Oomoo`00

1Goo00<007ooOol0EGoo00<007ooOol03Woo00L007ooOomoo`00Ool0000hOol2000UOol00`00Oomo

o`0<Ool01000Ool000000goo00<007oo00003goo000JOol00`00Oomoo`03Ool01000Oomoo`001Goo

00<007ooOol0Dgoo0P004Goo00L007ooOomoo`00Ool0000fOol2000WOol00`00Oomoo`0<Ool01000

Ool000000goo00<007oo00003goo000JOol00`00Oomoo`03Ool01000Ool000001Goo00<007ooOol0

Dgoo00<007ooOol047oo00L007ooOomoo`00Ool00009Ool3000YOol00`00Oomoo`0WOol00`00Oomo

o`0<Ool01000Ool000000goo00<007oo00002Goo0P0017oo000JOol00`00Oomoo`02Ool00`00Oomo

o`020004Ool00`00Oomoo`1DOol3000?Ool20004Ool00`00Oomoo`03Ool30004Ool00`00Oomoo`0U

Ool2000YOol2000>Ool01000Ool0000017oo00<007ooOol00goo0`0000Aoo`00000000Aoo`006Woo

0P000goo00@007oo000000Eoo`03001oogoo07Uoo`03001oogoo02=oo`8003]oo`03001oo`0000mo

o`03001oo`0000Aoo`006Woo00<007ooOol00Woo00@007oo000000Eoo`03001oogoo07Moo`8002Ao

o`8003eoo`03001oo`00011oo`03001oogoo00=oo`006Woo00<007ooOol00Woo0P0000=oo`00Ool0

17oo00<007ooOol0Mgoo0`008Goo0P00?Woo00@007ooOol0011oo`03001oogoo00=oo`006Woo00<0

07ooOol00Woo0`001Goo00<007ooOol0VWoo0P00@7oo00@007ooOol001Ioo`006Woo00<007ooOol0

0Woo0`001Goo00<007ooOol0VGoo00<007ooOol0@7oo00@007oo000001Ioo`006Wool0005Woo000J

Ool01000Oomoogoo0`001Woo00<007ooOol0J7oo00<007ooOol0:Woo0P00AGoo00@007oo000001Io

o`006Woo00@007ooOomoo`<000Eoo`03001oogoo06Uoo`03001oogoo02Qoo`8004Moo`04001oo`00

000FOol001Yoo`04001oogooOol30005Ool00`00Oomoo`2BOol20019Ool00`00Ool0000GOol001Yo

o`04001oogooOol20006Ool00`00Oomoo`2AOol00`00Oomoo`19Ool00`00Ool0000GOol001Yoo`04

001oogooOol20006Ool00`00Oomoo`2?Ool2001<Ool00`00Ool0000GOol001Yoo`80009oo`8000Eo

o`03001oogoo08ioo`8004ioo`03001oo`0001Moo`006Woo00@007ooOomoo`8000Eoo`03001oogoo

08eoo`03001oogoo04ioo`03001oo`0001Moo`006Woo00<007ooOol00`001Goo00<007ooOol0Rgoo

0P00DGoo00<007oo00005goo000JOol00`00Oomoo`030005Ool00`00Oomoo`29Ool2001BOol01000

Oomoo`005goo000JOol00`00Oomoo`020005Ool00`00Oomoo`29Ool00`00Oomoo`1BOol01000Oomo

o`005goo000JOol200000goo00000005Ool00`00Oomoo`27Ool2001EOol01000Oomoo`005goo000J

Ool00`00Oomoo`020005Ool00`00Oomoo`25Ool2001GOol01000Oomoo`005goo000JOol00`00Oomo

o`020005Ool00`00Oomoo`24Ool00`00Oomoo`1GOol01000Oomoo`005goo000JOol00`00Oomoo`02

0005Ool00`00Oomoo`22Ool2001JOol01000Oomoo`005goo000JOol00`00Oomoo`020004Ool00`00

Oomoo`21Ool2001LOol01000Oomoo`005goo000JOol200000goo001oo`04Ool00`00Oomoo`20Ool0

0`00Oomoo`1KOol01@00Oomoogoo00005goo000JOol01000Oomoo`001Goo00<007ooOol0OWoo0P00

GWoo00D007ooOomoo`0001Moo`006Woo00@007ooOol000Eoo`03001oogoo07aoo`80061oo`05001o

ogooOol0000GOol000Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool01000Oomoo`00

1Goo00<007ooOol0NWoo0P00HWoo00D007ooOomoo`0001Moo`001Goo00<007oo00001goo00<007oo

Ool00Woo00<007ooOol00goo00@007ooOol000Eoo`03001oogoo07Qoo`8006Aoo`05001oogooOol0

000GOol000Eoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo009oo`@000Aoo`03001oogoo

07Moo`8006Ioo`05001oogooOol0000GOol000Eoo`03001oo`0000Qoo`03001oogoo009oo`03001o

ogoo009oo`04001oo`000004Ool00`00Oomoo`1eOol2001XOol00`00Oomoo`02000GOol000Eoo`03

001oo`0000Moo`03001oo`00009oo`03001oo`0000=oo`04001oo`000004Ool00`00Oomoo`1cOol2

001ZOol00`00Oomoo`02000GOol000Ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009o

o`04001oo`000004Ool00`00Oomoo`1bOol00`00Oomoo`1YOol01000Oomoogoo0P005goo000JOol0

1000Ool0000017oo00<007ooOol0L7oo0P00K7oo00@007ooOomoo`8001Moo`006Woo00@007oo0000

00Aoo`03001oogoo06ioo`8006ioo`05001oogooOol0000HOol001Yoo`@000=oo`03001oogoo06io

o`03001oogoo06ioo`05001oogooOol0000HOol001Yoo`03001oo`0000Aoo`03001oogoo06aoo`80

075oo`05001oogooOol0000HOol001Yoo`03001oo`0000Aoo`03001oogoo06Yoo`8007=oo`05001o

ogooOol0000HOol001Yoo`03001oo`0000Aoo`03001oogoo06Qoo`8007Eoo`05001oogooOol0000H

Ool001Yoo`03001oo`0000Aoo`03001oogoo06Ioo`8007Ioo`03001oogoo009oo`03001oogoo01Io

o`006Woo0`0017oo00<007ooOol0I7oo0P00N7oo00@007ooOomoo`8001Qoo`006Woo00<007oo0000

0goo00<007ooOol0Hgoo0P00NWoo00@007ooOomoo`8001Qoo`006Woo00<007oo00000goo00<007oo

Ool0HGoo0P00O7oo00@007ooOomoo`8001Qoo`006Woo00<007oo00000goo00<007ooOol0H7oo00<0

07ooOol0O7oo00@007ooOomoo`8001Qoo`006Woo0`000goo00<007ooOol0GWoo0P00Ogoo00@007oo

Oomoo`8001Qoo`006Woo0`000goo00<007ooOol0G7oo0P00PGoo00@007ooOomoo`8001Qoo`006Woo

0`000goo00<007ooOol0Fgoo00<007ooOol0P7oo00<007ooOol00Woo0P0067oo000JOol30002Ool0

0`00Oomoo`1JOol20023Ool00`00Oomoo`02Ool2000HOol001Yoo`<0009oo`03001oogoo05Qoo`80

08Eoo`04001oogooOol3000HOol000Ioo`03001oogoo009oo`04001oogooOol30003Ool30002Ool3

0002Ool00`00Oomoo`1FOol20027Ool01000Oomoogoo0`0067oo0005Ool00`00Ool00007Ool00`00

Oomoo`04Ool01000Oomoogoo0`000Woo00<007ooOol0E7oo0P00RGoo00@007ooOomoo`<001Qoo`00

1Goo00<007oo000027oo00@007ooOomoo`@0009oo`<0009oo`03001oogoo059oo`8008]oo`04001o

ogooOol3000HOol000Eoo`03001oo`0000Qoo`07001oogooOol007oo00000goo0`000Woo00<007oo

Ool0D7oo0P00S7oo00<007ooOol00Woo0P006Goo0005Ool00`00Ool00007Ool00`00Ool00003Ool2

0003Ool30002Ool00`00Oomoo`1>Ool2002>Ool00`00Oomoo`02Ool2000IOol000Ioo`03001oogoo

00Moo`03001oogoo00=oo`04001oogooOol30002Ool00`00Oomoo`1=Ool00`00Oomoo`2>Ool01000

Oomoogoo0`006Goo000JOol20003Ool00`00Oomoo`1;Ool2002AOol01000Oomoogoo0`006Goo000J

Ool20002Ool00`00Oomoo`1:Ool2002COol01000Oomoogoo0`006Goo000JOol20002Ool00`00Oomo

o`19Ool00`00Oomoo`2COol01`00Oomoogoo001oo`0001Uoo`006Woo0P000Woo00<007ooOol0Agoo

0P00UGoo00@007ooOomoo`<001Yoo`006Woo0P000Woo00<007ooOol0AGoo0P00Ugoo00@007ooOomo

o`<001Yoo`006Woo0P000Woo00<007ooOol0@goo0P00VGoo00@007ooOomoo`<001Yoo`006Woo0P00

0Woo00<007ooOol0@Goo0P00Vgoo00@007ooOomoo`<001Yoo`006Woo0P000Woo00<007ooOol0?goo

0P00W7oo00<007ooOol00Woo00<007oo00006Woo000JOol20002Ool00`00Oomoo`0mOol2002NOol0

1000Oomoogoo0P0000=oo`00Ool06Goo000JOol20002Ool00`00Oomoo`0kOol2002POol01000Oomo

ogoo0P0000=oo`00Ool06Goo000JOol20002Ool00`00Oomoo`0jOol00`00Oomoo`2OOol00`00Oomo

o`02Ool01000Oomoo`006Woo000JOol20002Ool00`00Oomoo`0hOol2002ROol00`00Oomoo`02Ool0

1000Oomoo`006Woo000JOol20002Ool00`00Oomoo`0fOol2002TOol01000Oomoogoo0P000Woo00<0

07ooOol067oo000JOol200000goo001oo`0gOol00`00Oomoo`2SOol00`00Oomoo`02Ool01000Oomo

o`006goo000JOol200000goo001oo`0eOol2002VOol01000Oomoogoo0P000Woo00<007ooOol06Goo

0006Ool00`00Oomoo`02Ool01000Oomoogoo0`000Woo0P0017oo0P0000=oo`00Ool0<goo0P00Z7oo

00D007ooOomoo`0000=oo`03001oogoo01Uoo`001Goo00<007oo00001goo00<007ooOol00Woo00<0

07oo00000goo0P0000=oo`00Ool0<Woo00<007ooOol0Ygoo00<007ooOol00Woo00D007ooOomoo`00

01]oo`001Goo00<007oo000027oo00L007ooOomoo`00Ool00003Ool4000aOol2002ZOol01@00Oomo

ogoo00000goo00<007ooOol06Woo0005Ool00`00Ool00008Ool01000Oomoogoo0P0017oo0P0000=o

o`00Ool0;Woo0P00[7oo00D007ooOomoo`0000=oo`03001oogoo01Yoo`001Goo00<007oo00001goo

00<007oo00000Woo00<007ooOol00goo0P0000=oo`00Ool0;Goo00<007ooOol0[7oo00@007ooOol0

00Aoo`03001oogoo01Yoo`001Woo00<007ooOol01goo00<007ooOol00Woo0P000goo0P0000=oo`00

Ool0:goo0P00[Woo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`006Woo0P0000=oo`00Ool0:Goo

0P00/7oo00@007ooOol000Aoo`03001oogoo01]oo`006Woo0P0000=oo`00Ool09goo0P00/Goo00<0

07ooOol00P0017oo00<007ooOol06goo000JOol200000goo001oo`0UOol2002cOol01000Ool00000

17oo00<007ooOol077oo000JOol3000UOol2002dOol00`00Oomoo`020004Ool00`00Oomoo`0LOol0

01Yoo`<002=oo`800;Ioo`04001oo`000004Ool00`00Oomoo`0MOol001Yoo`<0029oo`03001oogoo

0;Eoo`05001oo`00Ool00004Ool00`00Oomoo`0MOol001Yoo`<0021oo`800;Moo`03001oogoo0080

00Aoo`03001oogoo01ioo`006Woo0`007goo00<007ooOol0]Woo00<007ooOol00P001Goo00<007oo

Ool07Woo000JOol3000MOol2002iOol01000Oomoo`001Goo00<007ooOol07goo000JOol3000LOol0

0`00Oomoo`2hOol01000Ool000001Woo00<007ooOol07goo000JOol3000JOol2002jOol00`00Ool0

00020005Ool00`00Oomoo`0POol001Yoo`<001Qoo`800;aoo`800003Ool007oo00Aoo`03001oogoo

025oo`006Woo0P005goo0P00_Goo10001Goo00<007ooOol08Woo000JOol2000EOol2002nOol01000

Ool000001Woo00<007ooOol08Woo000JOol2000COol2002oOol30007Ool00`00Oomoo`0SOol000Io

o`03001oogoo009oo`04001oogooOol30003Ool00`00Oomoo`02Ool2000AOol2002oOol40006Ool2

000VOol000Eoo`03001oo`0000Moo`03001oogoo009oo`03001oo`0000=oo`8000moo`800;moo`D0

00Ioo`03001oogoo02Ioo`001Goo00<007oo000027oo00L007ooOomoo`00Ool00003Ool3000<Ool2

0030Ool40006Ool2000YOol000Eoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo009oo`80

00]oo`800<1oo`@000Ioo`8002]oo`001Goo00<007oo00001goo00<007oo00000Woo00<007oo0000

0goo0P002Goo0P00`7oo10001goo00<007ooOol0:goo0006Ool00`00Oomoo`07Ool00`00Oomoo`02

Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`2mOol50003Ool6000^Ool001Yoo`03001oogoo00Eo

o`800;aoo`L00003Ool00000008003Aoo`006Woo0P0017oo0P00_7oo2P00>7oo000JOol01000Oomo

ogoo0P00]Goo3P00?Goo000JOol01000Ool00000[goo4@00@Woo000JOonk001;Ool001Yoo`03001o

ogoo0?moo`Aoo`006Woo0P00ogoo1Goo000JOol00`00Oomoo`3oOol4Ool001Yoo`03001oogoo0?mo

o`Aoo`006Woo00<007ooOol0ogoo17oo000JOol00`00Oomoo`3oOol4Ool001Yoo`03001oogoo0?mo

o`Aoo`006Woo0P00ogoo1Goo000JOol00`00Oomoo`3oOol4Ool001Yoo`03001oogoo0?moo`Aoo`00

2goo00<007ooOol00Woo00@007ooOomoo`8000Aoo`03001oogoo0?moo`Aoo`002Woo00<007oo0000

2Goo00D007ooOomoo`000?moo`Ioo`002Woo00<007oo000027oo00<007ooOol00Woo0`00ogoo17oo

000:Ool00`00Ool00009Ool00`00Oomoo`3oOol8Ool000Yoo`03001oo`0000Moo`03001oo`000?mo

o`Yoo`002goo00<007ooOol01goo00<007ooOol0ogoo2Goo003oOolQOol00?moob5oo`00ogoo8Goo

003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo

ob5oo`00\

\>"],

  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.13075*^-05, 0.146022, 

  4.19042*^-07, 0.000949233}}]

}, Open  ]],



Cell["\<\

 This table shows the convergence of the the electron current density jn .\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(Table[\(iterations[\([nn, 4]\)]\)[0], {nn, 7}]\)], "Input"],



Cell[BoxData[

    \({1\/10000000, 1.60945380618681994`*^-6, 7.99341519861592963`*^-6, 

      0.0000185219852380284493`, 0.0000167161287231154549`, 

      0.0000167056811593073391`, 0.0000167057789856071314`}\)], "Output"]

}, Open  ]],



Cell[" The convergence of jp.", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(Table[\(iterations[\([nn, 5]\)]\)[0], {nn, 7}]\)], "Input"],



Cell[BoxData[

    \({1\/10000000, 6.31568909358924912`*^-7, 2.80749294083032374`*^-6, 

      5.55738696862557723`*^-6, 5.01552299781945709`*^-6, 

      5.01048013474745701`*^-6, 5.00772494666950507`*^-6}\)], "Output"]

}, Open  ]],



Cell["The convergence of the electric field at 0, e0 .", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(-Table[\(iterations[\([nn, 1]\)]'\)[0], {nn, 7}]\)\)], "Input"],



Cell[BoxData[

    \({\(-4500.`\), \(-1699.55874800333521`\), \(-2002.1500783426589`\), 

      \(-2005.38105183544201`\), \(-2005.39316002818068`\), 

      \(-2005.38932976283668`\), \(-2005.41023046714084`\)}\)], "Output"]

}, Open  ]],



Cell[TextData[

" The converged potential, electron quasi-Fermi level, hole quasi-Fermi \

level, electron current, and hole current are given by vf, \[Phi]nf, \

\[Phi]pf, jnf and jpf."], "Text"],



Cell[BoxData[

    \(\({vf, \[Phi]nf, \[Phi]pf, jnf, jpf} = iterations[\([7]\)]; \)\)], 

  "Input"],



Cell["\<\

The total charge density can be calculated from the second derivative of the \

potential, per Poisson's equation.  Most of the junction is depleted of \

carriers.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(Plot[\(\(-\[Epsilon]\)\/q\) \(\(vf'\)'\)[x], {x, 0, l}, 

      PlotRange -> {\(-10\^15\), 10\^15}, 

      Ticks -> {{{5\ 10\^\(-5\), \*"\"\<5. \!\(10\^\(-5\)\)\>\""}, {

              10\^\(-4\), \*"\"\<1. \!\(10\^\(-4\)\)\>\""}}, Automatic}]; 

    \)\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 9523.81 0.309017 3.09017e-016 [

[.5 .29652 -21.375 -13.1875 ]

[.5 .29652 21.375 0 ]

[.97619 .29652 -21.375 -13.1875 ]

[.97619 .29652 21.375 0 ]

[.01131 0 -39 -6.25 ]

[.01131 0 0 6.25 ]

[.01131 .07725 -51 -6.25 ]

[.01131 .07725 0 6.25 ]

[.01131 .15451 -39 -6.25 ]

[.01131 .15451 0 6.25 ]

[.01131 .23176 -51 -6.25 ]

[.01131 .23176 0 6.25 ]

[.01131 .38627 -45 -6.25 ]

[.01131 .38627 0 6.25 ]

[.01131 .46353 -33 -6.25 ]

[.01131 .46353 0 6.25 ]

[.01131 .54078 -45 -6.25 ]

[.01131 .54078 0 6.25 ]

[.01131 .61803 -33 -6.25 ]

[.01131 .61803 0 6.25 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.5 .30902 m

.5 .31527 L

s

gsave

.5 .29652 -82.375 -17.1875 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 21.1875 translate 1 -1 scale

gsave

0.000000 0.000000 0.000000 setrgbcolor

1.000000 setlinewidth

gsave

newpath

 61.000000 17.187500 moveto

 464.000000 17.187500 lineto

 464.000000 4.000000 lineto

 61.000000 4.000000 lineto

 61.000000 17.187500 lineto

closepath

clip newpath

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(5.) show

81.000000 13.437500 moveto

(10) show

93.000000 9.187500 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

97.187500 9.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(5) show

101.750000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

grestore

grestore

%%DocumentNeededResources: font Math1Mono

%%+ font Courier

%%DocumentSuppliedResources:

%%DocumentNeededFonts: Math1Mono

%%+ Courier

%%DocumentSuppliedFonts:

%%DocumentFonts: font Math1Mono

%%+ font Courier

grestore

.97619 .30902 m

.97619 .31527 L

s

gsave

.97619 .29652 -82.375 -17.1875 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 21.1875 translate 1 -1 scale

gsave

0.000000 0.000000 0.000000 setrgbcolor

1.000000 setlinewidth

gsave

newpath

 61.000000 17.187500 moveto

 464.000000 17.187500 lineto

 464.000000 4.000000 lineto

 61.000000 4.000000 lineto

 61.000000 17.187500 lineto

closepath

clip newpath

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.) show

81.000000 13.437500 moveto

(10) show

93.000000 9.187500 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

97.187500 9.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(4) show

101.750000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

grestore

grestore

%%DocumentNeededResources: font Math1Mono

%%+ font Courier

%%DocumentSuppliedResources:

%%DocumentNeededFonts: Math1Mono

%%+ Courier

%%DocumentSuppliedFonts:

%%DocumentFonts: font Math1Mono

%%+ font Courier

grestore

0 .30902 m

1 .30902 L

s

.02381 0 m

.03006 0 L

s

gsave

.01131 0 -39 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(-1) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(15) show

grestore

.02381 .07725 m

.03006 .07725 L

s

gsave

.01131 .07725 -51 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(-7.5) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .15451 m

.03006 .15451 L

s

gsave

.01131 .15451 -39 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(-5) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .23176 m

.03006 .23176 L

s

gsave

.01131 .23176 -51 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(-2.5) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .38627 m

.03006 .38627 L

s

gsave

.01131 .38627 -45 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(2.5) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .46353 m

.03006 .46353 L

s

gsave

.01131 .46353 -33 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(5) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .54078 m

.03006 .54078 L

s

gsave

.01131 .54078 -45 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(7.5) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .61803 m

.03006 .61803 L

s

gsave

.01131 .61803 -33 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(1) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(15) show

grestore

.125 Mabswid

.02381 .01545 m

.02756 .01545 L

s

.02381 .0309 m

.02756 .0309 L

s

.02381 .04635 m

.02756 .04635 L

s

.02381 .0618 m

.02756 .0618 L

s

.02381 .09271 m

.02756 .09271 L

s

.02381 .10816 m

.02756 .10816 L

s

.02381 .12361 m

.02756 .12361 L

s

.02381 .13906 m

.02756 .13906 L

s

.02381 .16996 m

.02756 .16996 L

s

.02381 .18541 m

.02756 .18541 L

s

.02381 .20086 m

.02756 .20086 L

s

.02381 .21631 m

.02756 .21631 L

s

.02381 .24721 m

.02756 .24721 L

s

.02381 .26266 m

.02756 .26266 L

s

.02381 .27812 m

.02756 .27812 L

s

.02381 .29357 m

.02756 .29357 L

s

.02381 .32447 m

.02756 .32447 L

s

.02381 .33992 m

.02756 .33992 L

s

.02381 .35537 m

.02756 .35537 L

s

.02381 .37082 m

.02756 .37082 L

s

.02381 .40172 m

.02756 .40172 L

s

.02381 .41717 m

.02756 .41717 L

s

.02381 .43262 m

.02756 .43262 L

s

.02381 .44807 m

.02756 .44807 L

s

.02381 .47898 m

.02756 .47898 L

s

.02381 .49443 m

.02756 .49443 L

s

.02381 .50988 m

.02756 .50988 L

s

.02381 .52533 m

.02756 .52533 L

s

.02381 .55623 m

.02756 .55623 L

s

.02381 .57168 m

.02756 .57168 L

s

.02381 .58713 m

.02756 .58713 L

s

.02381 .60258 m

.02756 .60258 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

.5 Mabswid

.02381 .30891 m

.06244 .22459 L

.10458 .15384 L

.14415 .10241 L

.18221 .06498 L

.20178 .05001 L

.22272 .03697 L

.24402 .02643 L

.26416 .0188 L

.28414 .01308 L

.30258 .00922 L

.3213 .00638 L

.33207 .00495 L

.34193 .00392 L

.35121 .00328 L

.35611 .00288 L

.36134 .00247 L

.36284 .00236 L

.36357 .00231 L

.36425 .00228 L

.36552 .00223 L

.36618 .00222 L

.36689 .0022 L

.36807 .00219 L

.36934 .00217 L

.37007 .00216 L

.37074 .00214 L

.37204 .00208 L

.37697 .00176 L

.37946 .00164 L

.38221 .00152 L

.38468 .00139 L

.38597 .00132 L

.38667 .00128 L

.38733 .00126 L

.38852 .00123 L

.38983 .00123 L

.39094 .00123 L

.39213 .00123 L

.39331 .00123 L

.3946 .00121 L

.39581 .00117 L

.39693 .00112 L

.39904 .00103 L

.4013 .00094 L

.40378 .00088 L

.4061 .00082 L

.41138 .00072 L

.42206 .00053 L

.43219 .0004 L

Mistroke

.43497 .00037 L

.43649 .00035 L

.43724 .00034 L

.43792 .00034 L

.43857 .00033 L

.43926 .00033 L

.43995 .00033 L

.44071 .00033 L

.44202 .00035 L

.44323 .00038 L

.44449 .0004 L

.44519 .00041 L

.44585 .00042 L

.44704 .00042 L

.44832 .00039 L

.44945 .00034 L

.45052 .00028 L

.45294 .00013 L

.45422 6e-005 L

.45486 4e-005 L

.45556 2e-005 L

.4568 1e-005 L

.45795 2e-005 L

.45865 4e-005 L

.45931 5e-005 L

.46056 8e-005 L

.4612 .0001 L

.46189 .00011 L

.46264 .00012 L

.46334 .00013 L

.46455 .00013 L

.46524 .00013 L

.46588 .00013 L

.46828 .00012 L

.4728 .00011 L

.47392 .00011 L

.47514 .0001 L

.47647 .0001 L

.47772 9e-005 L

.48022 7e-005 L

.48295 5e-005 L

.48411 4e-005 L

.48536 3e-005 L

.48654 3e-005 L

.4876 2e-005 L

.48881 2e-005 L

.49012 2e-005 L

.49126 2e-005 L

.49251 2e-005 L

.49365 2e-005 L

Mistroke

.49472 2e-005 L

.49595 1e-005 L

.49707 1e-005 L

.49811 1e-005 L

Mfstroke

.49811 1e-005 m

.49811 0 L

s

.49982 0 m

.50014 .61803 L

.50128 .61803 L

.54194 .61776 L

.54312 .61776 L

.54423 .61779 L

.54551 .61783 L

.54667 .61786 L

.54777 .61788 L

.54879 .61788 L

.54991 .61787 L

.55109 .61784 L

.55215 .61781 L

.55328 .61778 L

.55453 .61777 L

.5557 .61776 L

.55834 .61773 L

.56075 .6177 L

.56592 .61765 L

.56728 .61764 L

.56873 .61763 L

.5701 .61762 L

.57135 .6176 L

.576 .61753 L

.57726 .61751 L

.57792 .6175 L

.57862 .61748 L

.57991 .61745 L

.58109 .61741 L

.5824 .61736 L

.58363 .61733 L

.58432 .61732 L

.58506 .61731 L

.58637 .61731 L

.58761 .61732 L

.58893 .61733 L

.59017 .61733 L

.5913 .61733 L

.592 .61732 L

.59275 .6173 L

.59408 .61726 L

.59708 .61714 L

.60252 .61694 L

.60368 .61687 L

.60492 .61681 L

.60556 .61678 L

.60628 .61676 L

.60753 .61674 L

.60871 .61675 L

.60997 .61677 L

Mistroke

.61117 .61678 L

.61226 .61678 L

.61296 .61678 L

.6136 .61676 L

.61431 .61674 L

.61506 .61671 L

.61772 .61654 L

.62269 .61629 L

.64239 .61512 L

.66074 .61359 L

.66198 .61348 L

.66268 .61344 L

.66332 .61343 L

.66456 .61342 L

.66573 .61342 L

.66694 .61337 L

.66825 .61324 L

.66895 .61314 L

.66969 .61302 L

.67102 .61279 L

.67377 .61241 L

.67523 .61218 L

.67681 .61188 L

.67751 .61178 L

.67824 .61169 L

.67956 .6116 L

.68025 .61157 L

.68091 .61155 L

.68214 .61147 L

.6833 .61132 L

.68455 .61109 L

.68713 .61059 L

.69177 .60963 L

.70231 .60794 L

.70465 .60727 L

.7058 .60697 L

.70687 .60678 L

.70809 .60666 L

.70879 .60662 L

.70943 .60657 L

.71056 .60643 L

.71177 .60617 L

.71714 .60454 L

.72217 .60337 L

.74321 .59666 L

.76249 .58868 L

.78332 .5776 L

.82436 .54739 L

.86389 .50623 L

.9019 .45443 L

Mistroke

.94237 .3841 L

.97619 .30898 L

Mfstroke

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{62, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ

Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00

ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000AOol5

00000goo001oo`02Ool60002Ool00`00Oomoo`3jOol001=oo`03001oogoo009oo`03001oo`0000=o

o`07001oogooOol007oo0000ngoo000=Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01`00

Oomoogoo001oo`000?]oo`004goo00<007ooOol00Woo00<007oo00000goo00L007ooOomoo`00Ool0

000@Ool3001BOolF0020Ool001=oo`05001oogooOol00003Ool01000Oomoo`000goo00<007oo0000

47oo00<007ooOol0@Goo4@005Goo00<007ooOol0OWoo000BOol20009Ool20004Ool01000Oomoogoo

0`000Woo0`001Woo00<007ooOol0>Woo1`009Woo00<007ooOol0OWoo000XOol00`00Oomoo`03Ool0

0`00Oomoo`04Ool00`00Oomoo`0fOol4000]Ool00`00Oomoo`1nOol002Qoo`03001oogoo00=oo`03

001oogoo00Aoo`8003=oo`@0035oo`03001oogoo07ioo`00:7oo00@007ooOomoo`8000Moo`03001o

ogoo031oo`8003Eoo`03001oogoo07ioo`009goo0P000goo0`001Woo00<007ooOol0;Woo0P00=goo

00<007ooOol0OWoo000eOol2000^Ool00`00Oomoo`0gOol00`00Oomoo`1nOol003Eoo`03001oogoo

02]oo`8003Yoo`03001oogoo07ioo`00=Goo00<007ooOol0:Goo0P00?7oo00<007ooOol0OWoo000e

Ool00`00Oomoo`0WOol2000nOol00`00Oomoo`1nOol003Eoo`8002Ioo`80041oo`03001oogoo07io

o`00=Goo00<007ooOol097oo00<007ooOol0@7oo00<007ooOol0OWoo000eOol00`00Oomoo`0SOol0

0`00Oomoo`11Ool00`00Oomoo`1nOol000Moo`03001oogoo009oo`03001oogoo009oo`05001oogoo

Ool00003Ool60002Ool00`00Oomoo`0AOol2000SOol00`00Oomoo`12Ool00`00Oomoo`1nOol000Mo

o`03001oogoo00Ioo`03001oo`0000=oo`03001oo`0000=oo`07001oogooOol007oo00004Woo00<0

07ooOol08Goo00<007ooOol0@goo00<007ooOol0OWoo000017oo000000000goo00<007ooOol027oo

00<007ooOol00Woo00<007ooOol00Woo00L007ooOomoo`00Ool0000BOol00`00Oomoo`0POol00`00

Oomoo`14Ool00`00Oomoo`1nOol000Qoo`03001oogoo00Eoo`8000Aoo`03001oo`0000=oo`07001o

ogooOol007oo00004Woo0`007goo00<007ooOol0AGoo00<007ooOol0OWoo0006Ool00`00Ool00007

Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00L007ooOomoo`00Ool0000BOol00`00Oomoo`0N

Ool00`00Oomoo`16Ool00`00Oomoo`1nOol000Ioo`<000Moo`<000Qoo`8000Aoo`04001oogooOol3

0003Ool20008Ool00`00Oomoo`0LOol20019Ool00`00Oomoo`1nOol002Ioo`04001oogooOol30008

Ool00`00Oomoo`0KOol00`00Oomoo`19Ool00`00Oomoo`1nOol002Ioo`07001oogooOol007oo0000

27oo0P006goo00<007ooOol0BWoo00<007ooOol0OWoo000VOol00`00Oomoo`02Ool00`00Oomoo`07

Ool00`00Oomoo`0IOol00`00Oomoo`1;Ool00`00Oomoo`1nOol002Eoo`8000Aoo`03001oogoo00Mo

o`03001oogoo01Qoo`03001oogoo04aoo`03001oogoo07ioo`00=Goo0P0067oo00<007ooOol0CGoo

00<007ooOol0OWoo000eOol00`00Oomoo`0FOol00`00Oomoo`1>Ool00`00Oomoo`1nOol003Eoo`03

001oogoo01Ioo`03001oogoo04ioo`03001oogoo07ioo`00=Goo00<007ooOol05Goo00<007ooOol0

Cgoo00<007ooOol0OWoo000eOol2000EOol00`00Oomoo`1@Ool00`00Oomoo`1nOol003Eoo`03001o

ogoo01=oo`03001oogoo055oo`03001oogoo07ioo`00=Goo00<007ooOol04goo00<007ooOol0DGoo

00<007ooOol0OWoo000COol01@00Oomoogoo00000goo1P000Woo00<007ooOol03goo0P004goo00<0

07ooOol0DWoo00<007ooOol0OWoo000BOol00`00Ool00003Ool00`00Ool00003Ool01`00Oomoogoo

001oo`00011oo`03001oogoo015oo`03001oogoo05=oo`03001oogoo07ioo`003Goo0`0017oo00<0

07ooOol00Woo00<007ooOol00Woo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`0@Ool00`00Oomo

o`1DOol00`00Oomoo`1nOol0019oo`8000Aoo`03001oo`0000=oo`07001oogooOol007oo000047oo

00<007ooOol047oo00<007ooOol0E7oo00<007ooOol0OWoo000BOol00`00Oomoo`02Ool01@00Oomo

ogoo00000Woo00L007ooOomoo`00Ool0000@Ool3000?Ool00`00Oomoo`1EOol00`00Oomoo`1nOol0

019oo`<000Qoo`8000Aoo`03001oogoo00moo`03001oogoo00ioo`03001oogoo05Ioo`03001oogoo

07ioo`009goo0`000goo0P001Woo00<007ooOol03Woo00<007ooOol0EWoo00<007ooOol0OWoo000X

Ool01000Oomoogoo0`001Woo0P003Woo00<007ooOol0Egoo00<007ooOol0OWoo000XOol01`00Oomo

ogoo001oo`0000Ioo`03001oogoo00eoo`03001oogoo05Moo`03001oogoo07ioo`00:7oo00<007oo

Ool00Woo00<007ooOol01Goo00<007ooOol037oo00<007ooOol0F7oo00<007ooOol0OWoo000WOol2

0004Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`1IOol00`00Oomoo`1nOol003Eoo`80

00aoo`03001oogoo05Uoo`03001oogoo07ioo`00=Goo00<007ooOol02Woo00<007ooOol0FWoo00<0

07ooOol0OWoo000eOol00`00Oomoo`0:Ool00`00Oomoo`1JOol00`00Oomoo`1nOol003Eoo`8000Yo

o`03001oogoo05]oo`03001oogoo07ioo`00=Goo00<007ooOol027oo00<007ooOol0G7oo00<007oo

Ool0OWoo000eOol00`00Oomoo`08Ool00`00Oomoo`1LOol00`00Oomoo`1nOol003Eoo`8000Qoo`03

001oogoo05eoo`03001oogoo07ioo`001Woo0`000goo00<007ooOol00Woo00D007ooOomoo`0000=o

o`H0009oo`03001oogoo015oo`03001oogoo00Moo`03001oogoo05eoo`03001oogoo07ioo`001Woo

00<007ooOol01goo00<007oo00000goo00<007oo00000goo00L007ooOomoo`00Ool0000BOol00`00

Oomoo`06Ool00`00Oomoo`1NOol00`00Oomoo`1nOol00004Ool000000003Ool00`00Oomoo`08Ool0

0`00Oomoo`02Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00019oo`03001oogoo00Ioo`03001o

ogoo05ioo`03001oogoo07ioo`001goo00<007ooOol01Woo0P0017oo00<007oo00000goo00L007oo

Oomoo`00Ool0000BOol30005Ool00`00Oomoo`1OOol00`00Oomoo`1nOol000Ioo`03001oo`0000Mo

o`03001oogoo009oo`05001oogooOol00002Ool01`00Oomoogoo001oo`00019oo`03001oogoo00Eo

o`03001oogoo05moo`03001oogoo07ioo`001goo00<007ooOol01Woo0`0027oo0P0017oo00@007oo

Oomoo`<000=oo`8000Qoo`03001oogoo00Aoo`03001oogoo061oo`03001oogoo07ioo`009Woo00@0

07ooOomoo`<000Qoo`8000Eoo`03001oogoo061oo`03001oogoo07ioo`009Woo00L007ooOomoo`00

Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`1QOol00`00Oomoo`1nOol002Ioo`03001oogoo009o

o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo065oo`03001oogoo07ioo`009Goo0P0017oo

00<007ooOol01goo00<007ooOol00Woo00<007ooOol0DGoo00<007ooOol00Woo00<007ooOol027oo

1@000Woo00<007ooOol0CWoo1@000Woo00<007ooOol027oo1@000Woo00<007ooOol03Woo000eOol2

0003Ool00`00Oomoo`1@Ool00`00Ool0000?Ool20003Ool00`00Ool0001AOol00`00Oomoo`0?Ool0

1`00Oomoogoo001oo`0000moo`00=Goo00D007ooOomoo`0005Eoo`03001oogoo00eoo`8000=oo`03

001oo`00055oo`03001oogoo00moo`07001oogooOol007oo00003goo000eOol01@00Oomoogoo0000

Dgoo0P0047oo0P000goo00<007oo0000DGoo00<007ooOol03goo00L007ooOomoo`00Ool0000?Ool0

03Eoo`800003Ool007oo05=oo`03001oogoo00moo`8000=oo`03001oo`0000Qoo`<004Ioo`03001o

ogoo00moo`07001oogooOol007oo00002Goo0P0017oo000eOol01000Oomoo`00E7oo0`003goo0P00

17oo00<007ooOol00goo0`000goo00<007ooOol0@goo0P0047oo0P0017oo00<007ooOol00goo0`00

00Aoo`00000000Aoo`00=Goo00<007oo0000Igoo00<007ooOol03goo00<007ooOol0IGoo00<007oo

000017oo000eOol00`00Ool0001WOol00`00Oomoo`0=Ool2001YOol00`00Oomoo`03Ool003Eoo`80

06Qoo`03001oogoo00eoo`<006Qoo`03001oogoo00=oo`00=Goo0P00J7oo00<007ooOol0OWoo000e

Ool00`00Oomoo`1WOol00`00Oomoo`1nOol0031ooml0015oo`00=Goo00<007ooOol0Igoo00<007oo

Ool0Igoo00<007ooOol057oo000eOol00`00Oomoo`1WOol00`00Oomoo`1VOol00`00Oomoo`0EOol0

03Eoo`8006Qoo`03001oogoo06Ioo`03001oogoo01Eoo`00=Goo00<007ooOol0Igoo00<007ooOol0

IGoo00<007ooOol05Woo000eOol00`00Oomoo`1WOol00`00Oomoo`1UOol00`00Oomoo`0FOol003Eo

o`03001oogoo06Moo`03001oogoo06Eoo`03001oogoo01Ioo`00=Goo0P00J7oo00<007ooOol0I7oo

00<007ooOol05goo000eOol00`00Oomoo`1WOol00`00Oomoo`1TOol00`00Oomoo`0GOol003Eoo`03

001oogoo06Moo`03001oogoo06=oo`03001oogoo01Qoo`00=Goo0P00J7oo00<007ooOol0Hgoo00<0

07ooOol067oo000eOol00`00Oomoo`1WOol00`00Oomoo`1ROol00`00Oomoo`0IOol003Eoo`03001o

ogoo06Moo`03001oogoo069oo`03001oogoo01Uoo`00=Goo00<007ooOol0Igoo00<007ooOol0HWoo

00<007ooOol06Goo0007Ool30003Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo1P000Woo00<0

07ooOol047oo0P00J7oo00<007ooOol0HGoo00<007ooOol06Woo0007Ool00`00Oomoo`07Ool00`00

Ool00003Ool00`00Ool00003Ool01`00Oomoogoo001oo`00015oo`03001oogoo06Moo`03001oogoo

065oo`03001oogoo01Yoo`0027oo00<007ooOol027oo00<007ooOol00Woo00<007ooOol00Woo00L0

07ooOomoo`00Ool0000AOol00`00Oomoo`1WOol00`00Oomoo`1POol00`00Oomoo`0KOol000Qoo`03

001oogoo00Ioo`8000Aoo`03001oo`0000=oo`07001oogooOol007oo00004Goo0`00Igoo00<007oo

Ool0H7oo00<007ooOol06goo0007Ool00`00Ool00007Ool00`00Oomoo`02Ool01@00Oomoogoo0000

0Woo00L007ooOomoo`00Ool0000AOol00`00Oomoo`1WOol00`00Oomoo`1OOol00`00Oomoo`0LOol0

00Qoo`03001oogoo00Ioo`<000Qoo`8000Aoo`04001oogooOol30003Ool20007Ool00`00Oomoo`1W

Ool00`00Oomoo`1OOol00`00Oomoo`0LOol002Moo`04001oogooOol30007Ool00`00Oomoo`1WOol0

0`00Oomoo`1NOol00`00Oomoo`0MOol002Moo`07001oogooOol007oo00001goo0P00J7oo00<007oo

Ool0GWoo00<007ooOol07Goo000WOol00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`1WOol0

0`00Oomoo`1MOol00`00Oomoo`0NOol002Ioo`8000Aoo`03001oogoo00Ioo`03001oogoo06Moo`03

001oogoo05aoo`03001oogoo01moo`00=Goo0P00J7oo00<007ooOol0G7oo00<007ooOol07goo000e

Ool00`00Oomoo`1WOol00`00Oomoo`1KOol00`00Oomoo`0POol003Eoo`03001oogoo06Moo`03001o

ogoo05]oo`03001oogoo021oo`00=Goo00<007ooOol0Igoo00<007ooOol0FWoo00<007ooOol08Goo

000eOol2001XOol00`00Oomoo`1IOol00`00Oomoo`0ROol003Eoo`03001oogoo06Moo`03001oogoo

05Uoo`03001oogoo029oo`00=Goo00<007ooOol0Igoo00<007ooOol0F7oo00<007ooOol08goo000D

Ool01@00Oomoogoo00000goo1P000Woo00<007ooOol03Woo0P00J7oo00<007ooOol0F7oo00<007oo

Ool08goo000COol00`00Ool00003Ool00`00Ool00003Ool01`00Oomoogoo001oo`0000moo`03001o

ogoo06Moo`03001oogoo05Moo`03001oogoo02Aoo`005Goo00<007ooOol00Woo00<007ooOol00Woo

00L007ooOomoo`00Ool0000?Ool00`00Oomoo`1WOol00`00Oomoo`1FOol00`00Oomoo`0UOol001=o

o`8000Aoo`03001oo`0000=oo`07001oogooOol007oo00003goo0`00Igoo00<007ooOol0EGoo00<0

07ooOol09Woo000COol00`00Oomoo`02Ool01@00Oomoogoo00000Woo00L007ooOomoo`00Ool0000?

Ool00`00Oomoo`1WOol00`00Oomoo`1EOol00`00Oomoo`0VOol001=oo`<000Qoo`8000Aoo`04001o

ogooOol30003Ool20005Ool00`00Oomoo`1WOol00`00Oomoo`1DOol00`00Oomoo`0WOol002Uoo`04

001oogooOol30005Ool00`00Oomoo`1WOol00`00Oomoo`1COol00`00Oomoo`0XOol002Uoo`07001o

ogooOol007oo00001Goo0P00J7oo00<007ooOol0DWoo00<007ooOol0:Goo000YOol00`00Oomoo`02

Ool00`00Oomoo`04Ool00`00Oomoo`1WOol00`00Oomoo`1BOol00`00Oomoo`0YOol002Qoo`8000Ao

o`03001oogoo00Aoo`03001oogoo06Moo`03001oogoo055oo`03001oogoo02Yoo`00=Goo0P00J7oo

00<007ooOol0D7oo00<007ooOol0:goo000eOol00`00Oomoo`1WOol00`00Oomoo`1?Ool00`00Oomo

o`0/Ool003Eoo`03001oogoo06Moo`03001oogoo04moo`03001oogoo02aoo`00=Goo00<007ooOol0

Igoo00<007ooOol0CWoo00<007ooOol0;Goo000eOol2001XOol00`00Oomoo`1=Ool00`00Oomoo`0^

Ool003Eoo`03001oogoo06Moo`03001oogoo04aoo`03001oogoo02moo`00=Goo00<007ooOol0Igoo

00<007ooOol0Bgoo00<007ooOol0<7oo0008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomo

ogoo00000goo1P000Woo00<007ooOol047oo0P00J7oo00<007ooOol0BWoo00<007ooOol0<Goo0008

Ool00`00Oomoo`06Ool00`00Ool00003Ool00`00Ool00003Ool01`00Oomoogoo001oo`00015oo`03

001oogoo06Moo`03001oogoo04Uoo`03001oogoo039oo`0027oo00<007ooOol027oo00<007ooOol0

0Woo00<007ooOol00Woo00L007ooOomoo`00Ool0000AOol00`00Oomoo`1WOol00`00Oomoo`18Ool0

0`00Oomoo`0cOol000Uoo`03001oogoo00Eoo`8000Aoo`03001oo`0000=oo`07001oogooOol007oo

00004Goo00<007ooOol0Igoo00<007ooOol0Agoo00<007ooOol0=7oo0007Ool00`00Ool00007Ool0

0`00Oomoo`02Ool01@00Oomoogoo00000Woo00L007ooOomoo`00Ool0000AOol3001WOol00`00Oomo

o`16Ool00`00Oomoo`0eOol000Moo`<000Moo`<000Qoo`8000Aoo`03001oogoo011oo`03001oogoo

06Moo`03001oogoo04Eoo`03001oogoo03Ioo`009Woo0`000goo0P001goo00<007ooOol0Igoo00<0

07ooOol0A7oo00<007ooOol0=goo000WOol01000Oomoogoo0`001goo0P00J7oo00<007ooOol0@Woo

0P00>Woo000WOol01`00Oomoogoo001oo`0000Moo`03001oogoo06Moo`03001oogoo045oo`03001o

ogoo03Yoo`009goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0Igoo00<007ooOol0@7oo

00<007ooOol0>goo000VOol20004Ool00`00Oomoo`06Ool2001XOol00`00Oomoo`0nOol2000nOol0

03Eoo`03001oogoo06Moo`03001oogoo03eoo`03001oogoo03ioo`00=Goo00<007ooOol0Igoo00<0

07ooOol0?7oo00<007ooOol0?goo000eOol00`00Oomoo`1WOol00`00Oomoo`0jOol20012Ool003Eo

o`8006Qoo`03001oogoo03Moo`<004Aoo`00=Goo00<007ooOol0Igoo00<007ooOol0=Goo0P00Agoo

000eOol00`00Oomoo`1WOol00`00Oomoo`0cOol20019Ool003Eoo`8006Qoo`03001oogoo035oo`80

04]oo`004Woo1@0000=oo`00Ool00Woo1P000Woo00<007ooOol03Woo00<007ooOol0Igoo00<007oo

Ool0:goo1P00CGoo000DOol00`00Oomoo`02Ool00`00Ool00003Ool01`00Oomoogoo001oo`0000mo

o`03001oogoo06Moo`03001oogoo02Aoo`L005=oo`0057oo00<007ooOol00goo00<007ooOol00Woo

00L007ooOomoo`00Ool0000?Ool00`00Oomoo`1WOol00`00Oomoo`0EOol@001IOol001Aoo`03001o

ogoo009oo`03001oo`0000=oo`07001oogooOol007oo00003goo0`00Igoo6000JGoo000DOol01@00

Oomoogoo00000goo00@007ooOol000=oo`03001oo`000?Yoo`004goo0P002Goo0P0017oo00@007oo

Oomoo`<0009oo`<00?1oo`00:Goo00<007ooOol00goo00<007ooOol0kWoo000YOol00`00Oomoo`03

Ool00`00Oomoo`3^Ool002Uoo`04001oogooOol2003aOol002Qoo`8000=oo`<00?1oo`00ogoo8Goo

003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo

ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\

\>"],

  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.53874*^-05, -1.28708*^15, 

  4.72049*^-07, 1.45484*^13}}]

}, Open  ]],



Cell["\<\

The electron and holes densities can be calculated from the potential and the \

quasi-Fermi levels.\

\>", "Text"],



Cell[CellGroupData[{



Cell[BoxData[

    \(\(Plot[{n[vf[x], \[Phi]nf[x]], p[vf[x], \[Phi]pf[x]]}, {x, 0, l}, 

      PlotRange -> All, 

      Ticks -> {{{5\ 10\^\(-5\), \*"\"\<5. \!\(10\^\(-5\)\)\>\""}, {

              10\^\(-4\), \*"\"\<1. \!\(10\^\(-4\)\)\>\""}}, Automatic}]; 

    \)\)], "Input"],



Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

/Mabs {

Mgmatrix idtransform

Mtmatrix dtransform

} bind def

/Mabsadd { Mabs

3 -1 roll add

3 1 roll add

exch } bind def

%% Graphics

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 9523.81 0.0147151 5.88536e-016 [

[.5 .00222 -21.375 -13.1875 ]

[.5 .00222 21.375 0 ]

[.97619 .00222 -21.375 -13.1875 ]

[.97619 .00222 21.375 0 ]

[.01131 .13242 -33 -6.25 ]

[.01131 .13242 0 6.25 ]

[.01131 .25013 -33 -6.25 ]

[.01131 .25013 0 6.25 ]

[.01131 .36784 -33 -6.25 ]

[.01131 .36784 0 6.25 ]

[.01131 .48554 -33 -6.25 ]

[.01131 .48554 0 6.25 ]

[.01131 .60325 -33 -6.25 ]

[.01131 .60325 0 6.25 ]

[ 0 0 0 0 ]

[ 1 .61803 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

0 g

.25 Mabswid

.5 .01472 m

.5 .02097 L

s

gsave

.5 .00222 -82.375 -17.1875 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 21.1875 translate 1 -1 scale

gsave

0.000000 0.000000 0.000000 setrgbcolor

1.000000 setlinewidth

gsave

newpath

 61.000000 17.187500 moveto

 464.000000 17.187500 lineto

 464.000000 4.000000 lineto

 61.000000 4.000000 lineto

 61.000000 17.187500 lineto

closepath

clip newpath

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(5.) show

81.000000 13.437500 moveto

(10) show

93.000000 9.187500 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

97.187500 9.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(5) show

101.750000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

grestore

grestore

%%DocumentNeededResources: font Math1Mono

%%+ font Courier

%%DocumentSuppliedResources:

%%DocumentNeededFonts: Math1Mono

%%+ Courier

%%DocumentSuppliedFonts:

%%DocumentFonts: font Math1Mono

%%+ font Courier

grestore

.97619 .01472 m

.97619 .02097 L

s

gsave

.97619 .00222 -82.375 -17.1875 Mabsadd m

1 1 Mabs scale

currentpoint translate

0 21.1875 translate 1 -1 scale

gsave

0.000000 0.000000 0.000000 setrgbcolor

1.000000 setlinewidth

gsave

newpath

 61.000000 17.187500 moveto

 464.000000 17.187500 lineto

 464.000000 4.000000 lineto

 61.000000 4.000000 lineto

 61.000000 17.187500 lineto

closepath

clip newpath

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

63.000000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(1.) show

81.000000 13.437500 moveto

(10) show

93.000000 9.187500 moveto

%%IncludeResource: font Math1Mono

%%IncludeFont: Math1Mono

/Math1Mono findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(-) show

97.187500 9.187500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 7.125000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

(4) show

101.750000 13.437500 moveto

%%IncludeResource: font Courier

%%IncludeFont: Courier

/Courier findfont 10.000000 scalefont

[1 0 0 -1 0 0 ] makefont setfont

0.000000 0.000000 0.000000 setrgbcolor

0.000000 0.000000 rmoveto

1.000000 setlinewidth

grestore

grestore

%%DocumentNeededResources: font Math1Mono

%%+ font Courier

%%DocumentSuppliedResources:

%%DocumentNeededFonts: Math1Mono

%%+ Courier

%%DocumentSuppliedFonts:

%%DocumentFonts: font Math1Mono

%%+ font Courier

grestore

0 .01472 m

1 .01472 L

s

.02381 .13242 m

.03006 .13242 L

s

gsave

.01131 .13242 -33 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(2) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .25013 m

.03006 .25013 L

s

gsave

.01131 .25013 -33 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(4) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .36784 m

.03006 .36784 L

s

gsave

.01131 .36784 -33 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(6) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .48554 m

.03006 .48554 L

s

gsave

.01131 .48554 -33 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(8) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(14) show

grestore

.02381 .60325 m

.03006 .60325 L

s

gsave

.01131 .60325 -33 -4.25 Mabsadd m

1 1 Mabs scale

/Courier findfont 10 scalefont setfont

(1) show

/Math1Mono findfont 10 scalefont setfont

(\\264) show

/Courier findfont 10 scalefont setfont

(10) show

0 5.25 rmoveto

/Courier findfont 7.5 scalefont setfont

(15) show

grestore

.125 Mabswid

.02381 .04414 m

.02756 .04414 L

s

.02381 .07357 m

.02756 .07357 L

s

.02381 .103 m

.02756 .103 L

s

.02381 .16185 m

.02756 .16185 L

s

.02381 .19128 m

.02756 .19128 L

s

.02381 .2207 m

.02756 .2207 L

s

.02381 .27956 m

.02756 .27956 L

s

.02381 .30898 m

.02756 .30898 L

s

.02381 .33841 m

.02756 .33841 L

s

.02381 .39726 m

.02756 .39726 L

s

.02381 .42669 m

.02756 .42669 L

s

.02381 .45612 m

.02756 .45612 L

s

.02381 .51497 m

.02756 .51497 L

s

.02381 .5444 m

.02756 .5444 L

s

.02381 .57382 m

.02756 .57382 L

s

.25 Mabswid

.02381 0 m

.02381 .61803 L

s

.5 Mabswid

.02381 .01472 m

.04262 .01472 L

.06244 .01472 L

.08426 .01472 L

.10458 .01472 L

.12414 .01472 L

.14264 .01472 L

.16305 .01472 L

.18163 .01472 L

.2016 .01472 L

.22004 .01472 L

.23877 .01472 L

.24942 .01472 L

.25939 .01472 L

.26977 .01472 L

.27964 .01472 L

.29817 .01472 L

.30775 .01472 L

.31797 .01472 L

.33636 .01472 L

.34664 .01472 L

.35777 .01472 L

.36828 .01472 L

.37794 .01472 L

.38768 .01472 L

.39677 .01472 L

.40674 .01472 L

.41743 .01472 L

.4276 .01473 L

.43867 .01473 L

.44912 .01474 L

.45879 .01474 L

.46842 .01475 L

.47745 .01476 L

.48737 .01478 L

.49806 .01481 L

.50763 .01484 L

.5181 .01489 L

.52903 .01496 L

.5392 .01505 L

.54972 .01517 L

.55965 .01533 L

.56857 .01551 L

.57824 .01575 L

.58771 .01605 L

.59812 .01648 L

.60899 .01706 L

.61916 .01774 L

.62957 .01862 L

.63945 .01966 L

Mistroke

.65798 .02229 L

.6676 .02409 L

.67783 .02639 L

.69623 .03175 L

.71768 .0405 L

.73786 .0518 L

.75798 .06672 L

.77647 .08417 L

.81601 .13566 L

.85403 .20587 L

.89451 .30519 L

.93347 .42783 L

.97488 .59708 L

.97619 .60332 L

Mfstroke

.02381 .60325 m

.06244 .44246 L

.10458 .30772 L

.14415 .20976 L

.18221 .13848 L

.20342 .10779 L

.22272 .08503 L

.24299 .0659 L

.26171 .05208 L

.28086 .04121 L

.30164 .03249 L

.32037 .02684 L

.33101 .02437 L

.34099 .02247 L

.35137 .02084 L

.36124 .01958 L

.37976 .01782 L

.38935 .01716 L

.39957 .01659 L

.40914 .01617 L

.41796 .01586 L

.42824 .01558 L

.43937 .01535 L

.44918 .01519 L

.45954 .01506 L

.46902 .01498 L

.47918 .01491 L

.48877 .01486 L

.49751 .01482 L

.50742 .01479 L

.51659 .01477 L

.52666 .01476 L

.53735 .01475 L

.54672 .01474 L

.55683 .01473 L

.56636 .01473 L

.57511 .01473 L

.58491 .01472 L

.59403 .01472 L

.60404 .01472 L

.61473 .01472 L

.62497 .01472 L

.63608 .01472 L

.64656 .01472 L

.65623 .01472 L

.66592 .01472 L

.67499 .01472 L

.68558 .01472 L

.69563 .01472 L

.70534 .01472 L

Mistroke

.71592 .01472 L

.73445 .01472 L

.7448 .01472 L

.75417 .01472 L

.7651 .01472 L

.77515 .01472 L

.79444 .01472 L

.80457 .01472 L

.81527 .01472 L

.83495 .01472 L

.85329 .01472 L

.87369 .01472 L

.89226 .01472 L

.91299 .01472 L

.93215 .01472 L

.97053 .01472 L

.97619 .01472 L

Mfstroke

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

% End of Graphics

MathPictureEnd

\

\>"], "Graphics",

  ImageSize->{288, 177.938},

  ImageMargins->{{62, 0}, {0, 0}},

  ImageRegion->{{0, 1}, {0, 1}},

  ImageCache->GraphicsData["Bitmap", "\<\

CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ

Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00

ogoo8Goo003oOolQOol008Eoo`03001oogoo009oo`03001oogoo00Qoo`D0009oo`03001oogoo05Mo

o`D0009oo`03001oogoo00Qoo`D0009oo`03001oogoo00ioo`00Q7oo00<007oo000047oo00L007oo

Oomoo`00Ool0001JOol00`00Oomoo`0?Ool01`00Oomoogoo001oo`0000moo`00QWoo00<007ooOol0

3Woo00L007ooOomoo`00Ool0001JOol00`00Oomoo`0?Ool01`00Oomoogoo001oo`0000moo`00Q7oo

0P004Goo00L007ooOomoo`00Ool0001JOol00`00Oomoo`0?Ool01`00Oomoogoo001oo`0000moo`00

Q7oo00<007ooOol047oo00L007ooOomoo`00Ool00008Ool3001?Ool00`00Oomoo`0?Ool01`00Oomo

ogoo001oo`0000Uoo`8000Aoo`00Q7oo0`003goo0P0017oo00<007ooOol00goo0`000goo00<007oo

Ool0C7oo0P0047oo0P0017oo00<007ooOol00goo0`0000Aoo`00000000Aoo`00Z7oo00<007ooOol0

KWoo00<007oo000017oo002VOol2001bOol00`00Oomoo`03Ool002Aoo`03001oogoo07moo`<0075o

o`03001oogoo00=oo`0097oo00<007ooOol0nGoo000TOol00`00Oomoo`3iOol001iooo80011oo`00

97oo00<007ooOol0CGoo30005Woo00<007ooOol05goo2P00Cgoo00<007ooOol057oo000TOol00`00

Oomoo`16Ool7000ROol00`00Oomoo`0QOol60019Ool00`00Oomoo`0DOol002Aoo`03001oogoo049o

o`@005=oo`@005aoo`0097oo00<007ooOol0?Woo1000Fgoo1000F7oo000TOol00`00Oomoo`0lOol2

001SOol2001FOol002Aoo`03001oogoo03Yoo`8006Moo`8005Aoo`0097oo00<007ooOol0>Goo00<0

07ooOol0JGoo0P00DWoo000TOol00`00Oomoo`0gOol2001^Ool2001@Ool002Aoo`03001oogoo03Io

o`03001oogoo071oo`03001oogoo04eoo`0097oo00<007ooOol0=7oo0P00M7oo00<007ooOol0C7oo

000TOol00`00Oomoo`0bOol2001gOol2001<Ool002Aoo`03001oogoo035oo`03001oogoo07Uoo`03

001oogoo04Uoo`0097oo00<007ooOol0<7oo00<007ooOol0Ngoo00<007ooOol0B7oo000TOol00`00

Oomoo`0_Ool00`00Oomoo`1mOol00`00Oomoo`17Ool002Aoo`03001oogoo02ioo`03001oogoo07mo

o`03001oogoo04Ioo`0097oo00<007ooOol0;Goo00<007ooOol0PGoo00<007ooOol0AGoo000TOol0

0`00Oomoo`0/Ool00`00Oomoo`23Ool00`00Oomoo`14Ool002Aoo`03001oogoo02]oo`03001oogoo

08Eoo`03001oogoo04=oo`0097oo00<007ooOol0:Woo00<007ooOol0Qgoo00<007ooOol0@Woo000T

Ool00`00Oomoo`0ZOol00`00Oomoo`28Ool00`00Oomoo`11Ool002Aoo`03001oogoo02Uoo`03001o

ogoo08Uoo`03001oogoo045oo`0097oo00<007ooOol0:7oo00<007ooOol0Rgoo00<007ooOol0@7oo

000TOol00`00Oomoo`0WOol00`00Oomoo`2=Ool00`00Oomoo`0oOol002Aoo`03001oogoo02Moo`03

001oogoo08ioo`03001oogoo03ioo`0000Aoo`000000009oo`04001oogooOol60002Ool00`00Oomo

o`0?Ool00`00Oomoo`0VOol00`00Oomoo`2@Ool00`00Oomoo`0mOol00003Ool007oo00Aoo`03001o

o`0000=oo`07001oogooOol007oo000047oo00<007ooOol09Goo00<007ooOol0TWoo00<007ooOol0

?7oo0002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00011oo`03001oogoo

02Eoo`03001oogoo099oo`03001oogoo03aoo`000Woo00<007ooOol00Woo00<007oo00000goo00L0

07ooOomoo`00Ool0000@Ool2000UOol00`00Oomoo`2DOol00`00Oomoo`0kOol00004Ool007oo0002

Ool01@00Oomoogoo00000Woo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`0TOol00`00Oomoo`2E

Ool00`00Oomoo`0jOol0009oo`03001oogoo00Moo`8000Aoo`04001oogooOol30003Ool20006Ool0

0`00Oomoo`0SOol00`00Oomoo`2GOol00`00Oomoo`0iOol001Moo`04001oogooOol30006Ool00`00

Oomoo`0ROol00`00Oomoo`2HOol00`00Oomoo`0iOol001Moo`07001oogooOol007oo00001Woo00<0

07ooOol08Woo00<007ooOol0VGoo00<007ooOol0>7oo000GOol00`00Oomoo`02Ool00`00Oomoo`05

Ool00`00Oomoo`0QOol00`00Oomoo`2JOol00`00Oomoo`0hOol001Ioo`8000Aoo`03001oogoo00Eo

o`03001oogoo025oo`03001oogoo09]oo`03001oogoo03Moo`0097oo00<007ooOol087oo00<007oo

Ool0W7oo00<007ooOol0=goo000TOol00`00Oomoo`0POol00`00Oomoo`2MOol00`00Oomoo`0fOol0

02Aoo`03001oogoo01moo`03001oogoo09ioo`03001oogoo03Ioo`0097oo00<007ooOol07goo00<0

07ooOol0Wgoo00<007ooOol0=Goo000TOol00`00Oomoo`0NOol00`00Oomoo`2POol00`00Oomoo`0e

Ool002Aoo`03001oogoo01ioo`03001oogoo0:5oo`03001oogoo03Aoo`0097oo00<007ooOol07Goo

00<007ooOol0XWoo00<007ooOol0=7oo000TOol00`00Oomoo`0MOol00`00Oomoo`2SOol00`00Oomo

o`0cOol002Aoo`03001oogoo01aoo`03001oogoo0:Aoo`03001oogoo03=oo`0097oo00<007ooOol0

77oo00<007ooOol0YGoo00<007ooOol0<Woo000TOol00`00Oomoo`0KOol00`00Oomoo`2VOol00`00

Oomoo`0bOol002Aoo`03001oogoo01]oo`03001oogoo0:Moo`03001oogoo035oo`0097oo00<007oo

Ool06Woo00<007ooOol0Z7oo00<007ooOol0<Goo000TOol00`00Oomoo`0JOol00`00Oomoo`2YOol0

0`00Oomoo`0`Ool002Aoo`03001oogoo01Uoo`03001oogoo0:Yoo`03001oogoo031oo`0097oo00<0

07ooOol06Goo00<007ooOol0Zgoo00<007ooOol0;goo000TOol00`00Oomoo`0HOol00`00Oomoo`2/

Ool00`00Oomoo`0_Ool002Aoo`03001oogoo01Qoo`03001oogoo0:aoo`03001oogoo02moo`0097oo

00<007ooOol05goo00<007ooOol0[Woo00<007ooOol0;Woo0002Ool300000goo001oo`02Ool60002

Ool00`00Oomoo`0?Ool00`00Oomoo`0GOol00`00Oomoo`2^Ool00`00Oomoo`0^Ool000=oo`07001o

ogooOol007oo00000goo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`0GOol00`00Oomoo`2^Ool0

0`00Oomoo`0^Ool00003Ool00000008000=oo`03001oogoo009oo`07001oogooOol007oo000047oo

00<007ooOol05Woo00<007ooOol0/7oo00<007ooOol0;Goo000017oo001oo`000goo00<007oo0000

0goo00L007ooOomoo`00Ool0000@Ool2000GOol00`00Oomoo`2`Ool00`00Oomoo`0]Ool0009oo`80

009oo`05001oogooOol00002Ool01`00Oomoogoo001oo`00011oo`03001oogoo01Eoo`03001oogoo

0;9oo`03001oogoo02aoo`000goo00<007ooOol01Woo0P0017oo00@007ooOomoo`<000=oo`8000Io

o`03001oogoo01Eoo`03001oogoo0;9oo`03001oogoo02aoo`005goo00@007ooOomoo`<000Ioo`03

001oogoo01Eoo`03001oogoo0;9oo`03001oogoo02aoo`005goo00L007ooOomoo`00Ool00006Ool0

0`00Oomoo`0DOol00`00Oomoo`2dOol00`00Oomoo`0[Ool001Moo`03001oogoo009oo`03001oogoo

00Eoo`03001oogoo01Aoo`03001oogoo0;Aoo`03001oogoo02]oo`005Woo0P0017oo00<007ooOol0

1Goo00<007ooOol04goo00<007ooOol0]Goo00<007ooOol0:goo000TOol00`00Oomoo`0COol00`00

Oomoo`2fOol00`00Oomoo`0ZOol002Aoo`03001oogoo019oo`03001oogoo0;Moo`03001oogoo02Yo

o`0097oo00<007ooOol04Woo00<007ooOol0^7oo00<007ooOol0:Goo000TOol00`00Oomoo`0BOol0

0`00Oomoo`2hOol00`00Oomoo`0YOol002Aoo`03001oogoo015oo`03001oogoo0;Uoo`03001oogoo

02Uoo`0097oo00<007ooOol04Goo00<007ooOol0^Woo00<007ooOol0:7oo000TOol00`00Oomoo`0@

Ool00`00Oomoo`2kOol00`00Oomoo`0XOol002Aoo`03001oogoo011oo`03001oogoo0;]oo`03001o

ogoo02Qoo`0097oo00<007ooOol047oo00<007ooOol0_7oo00<007ooOol09goo000TOol00`00Oomo

o`0?Ool00`00Oomoo`2mOol00`00Oomoo`0WOol002Aoo`03001oogoo00moo`03001oogoo0;eoo`03

001oogoo02Moo`0097oo00<007ooOol03goo00<007ooOol0_Woo00<007ooOol09Woo000TOol00`00

Oomoo`0>Ool00`00Oomoo`2oOol00`00Oomoo`0VOol002Aoo`03001oogoo00ioo`03001oogoo0;mo

o`03001oogoo02Ioo`0097oo00<007ooOol03Woo00<007ooOol0`7oo00<007ooOol09Goo000TOol0

0`00Oomoo`0=Ool00`00Oomoo`31Ool00`00Oomoo`0UOol002Aoo`03001oogoo00eoo`03001oogoo

0<5oo`03001oogoo02Eoo`0097oo00<007ooOol03Goo00<007ooOol0`Woo00<007ooOol097oo0000

0goo00000003Ool01000Oomoogoo1P000Woo00<007ooOol03goo00<007ooOol03Goo00<007ooOol0

`Woo00<007ooOol097oo000017oo001oo`000goo00<007oo00000goo00L007ooOomoo`00Ool0000@

Ool00`00Oomoo`0<Ool00`00Oomoo`33Ool00`00Oomoo`0TOol00004Ool007oo0004Ool00`00Oomo

o`02Ool01`00Oomoogoo001oo`00011oo`03001oogoo00aoo`03001oogoo0<Aoo`03001oogoo02=o

o`0000=oo`00000017oo00<007oo00000goo00L007ooOomoo`00Ool0000@Ool2000=Ool00`00Oomo

o`34Ool00`00Oomoo`0SOol00003Ool007oo00=oo`05001oogooOol00002Ool01`00Oomoogoo001o

o`00011oo`03001oogoo00]oo`03001oogoo0<Eoo`03001oogoo02=oo`000Woo0P0027oo0P0017oo

00@007ooOomoo`<000=oo`8000Ioo`03001oogoo00]oo`03001oogoo0<Ioo`03001oogoo029oo`00

5goo00@007ooOomoo`<000Ioo`03001oogoo00]oo`03001oogoo0<Ioo`03001oogoo029oo`005goo

00L007ooOomoo`00Ool00006Ool00`00Oomoo`0:Ool00`00Oomoo`37Ool00`00Oomoo`0ROol001Mo

o`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo0<Qoo`03001oogoo025o

o`005Woo0P0017oo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol0b7oo00<007ooOol08Goo

000TOol00`00Oomoo`09Ool00`00Oomoo`39Ool00`00Oomoo`0QOol002Aoo`03001oogoo00Uoo`03

001oogoo0<Yoo`03001oogoo021oo`0097oo00<007ooOol02Goo00<007ooOol0bWoo00<007ooOol0

87oo000TOol00`00Oomoo`08Ool00`00Oomoo`3;Ool00`00Oomoo`0POol002Aoo`03001oogoo00Qo

o`03001oogoo0<aoo`03001oogoo01moo`0097oo00<007ooOol027oo00<007ooOol0c7oo00<007oo

Ool07goo000TOol00`00Oomoo`08Ool00`00Oomoo`3<Ool00`00Oomoo`0OOol002Aoo`03001oogoo

00Moo`03001oogoo0<ioo`03001oogoo01ioo`0097oo00<007ooOol01goo00<007ooOol0cWoo00<0

07ooOol07Woo000TOol00`00Oomoo`07Ool00`00Oomoo`3>Ool00`00Oomoo`0NOol002Aoo`03001o

ogoo00Ioo`03001oogoo0=1oo`03001oogoo01eoo`0097oo00<007ooOol01Woo00<007ooOol0d7oo

00<007ooOol07Goo000TOol00`00Oomoo`06Ool00`00Oomoo`3@Ool00`00Oomoo`0MOol002Aoo`03

001oogoo00Ioo`03001oogoo0=1oo`03001oogoo01eoo`0097oo00<007ooOol01Goo00<007ooOol0

dWoo00<007ooOol077oo000TOol00`00Oomoo`05Ool00`00Oomoo`3BOol00`00Oomoo`0LOol002Ao

o`03001oogoo00Eoo`03001oogoo0=9oo`03001oogoo01aoo`0097oo00<007ooOol01Goo00<007oo

Ool0dWoo00<007ooOol077oo0002Ool01@00Oomoogoo00000goo1P000Woo00<007ooOol03goo00<0

07ooOol017oo00<007ooOol0e7oo00<007ooOol06goo000017oo001oo`000goo00<007oo00000goo

00L007ooOomoo`00Ool0000@Ool00`00Oomoo`04Ool00`00Oomoo`3DOol00`00Oomoo`0KOol00004

Ool007oo0004Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00011oo`03001oogoo00Aoo`03001o

ogoo0=Aoo`03001oogoo01]oo`000Woo00<007ooOol00Woo00<007oo00000goo00L007ooOomoo`00

Ool0000@Ool00`00Oomoo`04Ool00`00Oomoo`3DOol00`00Oomoo`0KOol00004Ool007oo0002Ool0

1@00Oomoogoo00000Woo00L007ooOomoo`00Ool0000@Ool20004Ool00`00Oomoo`3FOol00`00Oomo

o`0JOol0009oo`03001oogoo00Moo`8000Aoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo

0=Ioo`03001oogoo01Yoo`005Woo0`000goo0P001Woo00<007ooOol00goo00<007ooOol0eWoo00<0

07ooOol06Woo000GOol01000Oomoogoo0`001Woo00<007ooOol00goo00<007ooOol0eWoo00<007oo

Ool06Woo000GOol01`00Oomoogoo001oo`0000Ioo`03001oogoo00=oo`03001oogoo0=Moo`03001o

ogoo01Uoo`005goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0f7oo

00<007ooOol06Goo000FOol20004Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`3HOol0

0`00Oomoo`0IOol002Aoo`03001oogoo009oo`03001oogoo0=Qoo`03001oogoo01Uoo`0097oo00<0

07ooOol00Woo00<007ooOol0fGoo00<007ooOol067oo000TOol01@00Oomoogoo0000g7oo00<007oo

Ool067oo000TOol01@00Oomoogoo0000g7oo00<007ooOol067oo000TOol01@00Oomoogoo0000g7oo

00<007ooOol067oo000TOol01@00Oomoogoo0000gGoo00<007ooOol05goo000TOol01000Oomoo`00

gWoo00<007ooOol05goo000TOol01000Oomoo`00gWoo00<007ooOol05goo000TOol01000Oomoo`00

gWoo00<007ooOol05goo000TOol01000Oomoo`00ggoo00<007ooOol05Woo000TOol01000Oomoo`00

ggoo00<007ooOol05Woo000TOol00`00Ool0003POol00`00Oomoo`0FOol002Aoo`03001oo`000>1o

o`03001oogoo01Ioo`0097oo00<007oo0000hGoo00<007ooOol05Goo000TOol00`00Ool0003QOol0

0`00Oomoo`0EOol002Aoo`800>9oo`03001oogoo01Eoo`0097oo0P00hWoo00<007ooOol05Goo000T

Ool2003SOol00`00Oomoo`0DOol000D00003Ool007oo009oo`H0009oo`03001oogoo00moo`800>=o

o`03001oogoo01Aoo`000Woo00<007ooOol00Woo00<007oo00000goo00L007ooOomoo`00Ool0000@

Ool00`00Oomoo`3ROol00`00Oomoo`0DOol0009oo`03001oogoo00=oo`03001oogoo009oo`07001o

ogooOol007oo000047oo00<007ooOol0hWoo00<007ooOol057oo0002Ool00`00Oomoo`02Ool00`00

Ool00003Ool01`00Oomoogoo001oo`00011oo`800>=oo`03001oogoo01Aoo`000Woo00D007ooOomo

o`0000=oo`04001oogoo0003Ool00`00Ool0000@Ool00`00Oomoo`3iOol00003Ool0000000Uoo`80

00Aoo`04001oogooOol30002Ool30006Ool00`00Oomoo`3iOol001Moo`03001oogoo00=oo`03001o

ogoo00Aoo`03001oogoo0?Uoo`005goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0nGoo

000GOol01000Oomoogoo0P00ogoo17oo000FOol20003Ool3003oOol3Ool00?moob5oo`00ogoo8Goo

003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\

\>"],

  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.56852*^-05, -1.58565*^14, 

  4.35522*^-07, 7.04771*^12}}]

}, Open  ]]

}, Open  ]],



Cell["Conclusion", "Subtitle",

  TextAlignment->Center,

  FontSlant->"Italic"],



Cell[TextData[{

  "Complex coupled nonlinear boundary value differential equations can be \

solved in ",

  StyleBox["Mathematica",

    FontSlant->"Italic"],

  " using quasi-linearization by taking advantage of ",

  StyleBox["Mathematica",

    FontSlant->"Italic"],

  "'s unique use of interpolating functions for the numerical solution of \

differential equations."

}], "Text"]

},

FrontEndVersion->"Microsoft Windows 3.0",

ScreenRectangle->{{0, 1152}, {0, 798}},

ScreenStyleEnvironment->"Presentation",

ShowPageBreaks->True,

CellGrouping->Manual,

WindowSize->{887, 635},

WindowMargins->{{0, Automatic}, {Automatic, 5}},

PrintingCopies->1,

PrintingPageRange->{Automatic, Automatic},

PrivateFontOptions->{"FontType"->"Outline"},

Magnification->1.5,

StyleDefinitions -> "Report.nb"

]





(***********************************************************************

Cached data follows.  If you edit this Notebook file directly, not using

Mathematica, you must remove the line containing CacheID at the top of 

the file.  The cache data will then be recreated when you save this file 

from within Mathematica.

***********************************************************************)



(*CellTagsOutline

CellTagsIndex->{}

*)



(*CellTagsIndex

CellTagsIndex->{}

*)



(*NotebookFileOutline

Notebook[{

Cell[1709, 49, 132, 4, 129, "Title"],

Cell[1844, 55, 83, 4, 79, "Subtitle"],

Cell[1930, 61, 108, 3, 33, "Text"],

Cell[2041, 66, 81, 2, 46, "Subtitle"],

Cell[2125, 70, 1010, 16, 205, "Text"],



Cell[CellGroupData[{

Cell[3160, 90, 86, 2, 46, "Subtitle"],

Cell[3249, 94, 539, 8, 98, "Text"],



Cell[CellGroupData[{

Cell[3813, 106, 323, 7, 145, "Input"],

Cell[4139, 115, 167, 3, 63, "Message"],

Cell[4309, 120, 119, 3, 60, "Output"]

}, Open  ]],

Cell[4443, 126, 208, 4, 55, "Text"],



Cell[CellGroupData[{

Cell[4676, 134, 351, 8, 145, "Input"],

Cell[5030, 144, 119, 3, 60, "Output"]

}, Open  ]],

Cell[5164, 150, 49, 0, 33, "Text"],



Cell[CellGroupData[{

Cell[5238, 154, 45, 1, 60, "Input"],

Cell[5286, 157, 56, 1, 60, "Output"]

}, Open  ]],

Cell[5357, 161, 309, 5, 76, "Text"],

Cell[5669, 168, 320, 5, 76, "Text"],

Cell[5992, 175, 246, 6, 103, "Input"],

Cell[6241, 183, 82, 1, 60, "Input"],



Cell[CellGroupData[{

Cell[6348, 188, 123, 3, 60, "Input"],

Cell[6474, 193, 252, 6, 60, "Output"]

}, Open  ]],

Cell[6741, 202, 107, 3, 33, "Text"],

Cell[6851, 207, 50, 1, 60, "Input"],

Cell[6904, 210, 157, 3, 81, "Input"],

Cell[7064, 215, 241, 4, 55, "Text"],

Cell[7308, 221, 249, 6, 124, "Input"],

Cell[7560, 229, 117, 3, 33, "Text"],



Cell[CellGroupData[{

Cell[7702, 236, 64, 1, 60, "Input"],

Cell[7769, 239, 370, 6, 83, "Message"]

}, Open  ]],

Cell[8154, 248, 56, 0, 33, "Text"],



Cell[CellGroupData[{

Cell[8235, 252, 79, 1, 60, "Input"],

Cell[8317, 255, 19209, 594, 290, 6440, 432, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]],

Cell[27541, 852, 70, 0, 33, "Text"],



Cell[CellGroupData[{

Cell[27636, 856, 46, 1, 60, "Input"],

Cell[27685, 859, 72, 1, 60, "Output"]

}, Open  ]],



Cell[CellGroupData[{

Cell[27794, 865, 46, 1, 60, "Input"],

Cell[27843, 868, 206, 3, 60, "Output"]

}, Open  ]],

Cell[28064, 874, 105, 3, 33, "Text"],



Cell[CellGroupData[{

Cell[28194, 881, 66, 1, 60, "Input"],

Cell[28263, 884, 216, 3, 60, "Output"]

}, Open  ]]

}, Open  ]],



Cell[CellGroupData[{

Cell[28528, 893, 101, 2, 46, "Subtitle"],

Cell[28632, 897, 187, 4, 55, "Text"],

Cell[28822, 903, 442, 8, 78, "Text"],

Cell[29267, 913, 146, 2, 81, "Input"],

Cell[29416, 917, 148, 3, 33, "Text"],

Cell[29567, 922, 107, 2, 60, "Input"],

Cell[29677, 926, 449, 7, 98, "Text"],

Cell[30129, 935, 281, 4, 220, "Input"],

Cell[30413, 941, 68, 0, 33, "Text"],

Cell[30484, 943, 70, 1, 60, "Input"],

Cell[30557, 946, 127, 3, 33, "Text"],



Cell[CellGroupData[{

Cell[30709, 953, 373, 5, 124, "Input"],

Cell[31085, 960, 2098, 48, 267, "Output"]

}, Open  ]],

Cell[33198, 1011, 224, 3, 55, "Text"],

Cell[33425, 1016, 168, 2, 81, "Input"],

Cell[33596, 1020, 62, 0, 33, "Text"],

Cell[33661, 1022, 621, 10, 253, "Input"],

Cell[34285, 1034, 504, 15, 78, "Text"],

Cell[34792, 1051, 103, 2, 80, "Input"],

Cell[34898, 1055, 116, 3, 33, "Text"],

Cell[35017, 1060, 227, 3, 103, "Input"],

Cell[35247, 1065, 247, 4, 55, "Text"],



Cell[CellGroupData[{

Cell[35519, 1073, 83, 1, 84, "Input"],

Cell[35605, 1076, 55, 1, 60, "Output"]

}, Open  ]],

Cell[35675, 1080, 211, 4, 55, "Text"],



Cell[CellGroupData[{

Cell[35911, 1088, 181, 5, 60, "Input"],

Cell[36095, 1095, 54, 1, 60, "Output"]

}, Open  ]],



Cell[CellGroupData[{

Cell[36186, 1101, 185, 5, 60, "Input"],

Cell[36374, 1108, 55, 1, 60, "Output"]

}, Open  ]],

Cell[36444, 1112, 251, 4, 55, "Text"],

Cell[36698, 1118, 325, 5, 145, "Input"],

Cell[37026, 1125, 292, 5, 76, "Text"],

Cell[37321, 1132, 604, 11, 230, "Input"],

Cell[37928, 1145, 173, 3, 55, "Text"],

Cell[38104, 1150, 235, 4, 81, "Input"],

Cell[38342, 1156, 248, 4, 55, "Text"],



Cell[CellGroupData[{

Cell[38615, 1164, 73, 1, 60, "Input"],

Cell[38691, 1167, 159, 3, 63, "Message"],

Cell[38853, 1172, 800, 13, 103, "Message"]

}, Open  ]],

Cell[39668, 1188, 67, 0, 33, "Text"],



Cell[CellGroupData[{

Cell[39760, 1192, 267, 5, 82, "Input"],

Cell[40030, 1199, 16745, 562, 290, 8158, 452, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]],

Cell[56790, 1764, 94, 1, 33, "Text"],



Cell[CellGroupData[{

Cell[56909, 1769, 376, 7, 124, "Input"],

Cell[57288, 1778, 34596, 1524, 290, 22185, 1366, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]],

Cell[91899, 3305, 98, 2, 33, "Text"],



Cell[CellGroupData[{

Cell[92022, 3311, 79, 1, 60, "Input"],

Cell[92104, 3314, 221, 3, 98, "Output"]

}, Open  ]],

Cell[92340, 3320, 39, 0, 33, "Text"],



Cell[CellGroupData[{

Cell[92404, 3324, 79, 1, 60, "Input"],

Cell[92486, 3327, 217, 3, 98, "Output"]

}, Open  ]],

Cell[92718, 3333, 64, 0, 33, "Text"],



Cell[CellGroupData[{

Cell[92807, 3337, 85, 1, 60, "Input"],

Cell[92895, 3340, 222, 3, 60, "Output"]

}, Open  ]],

Cell[93132, 3346, 193, 3, 55, "Text"],

Cell[93328, 3351, 98, 2, 60, "Input"],

Cell[93429, 3355, 186, 4, 55, "Text"],



Cell[CellGroupData[{

Cell[93640, 3363, 285, 5, 107, "Input"],

Cell[93928, 3370, 23731, 798, 290, 11596, 644, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]],

Cell[117674, 4171, 123, 3, 33, "Text"],



Cell[CellGroupData[{

Cell[117822, 4178, 275, 5, 82, "Input"],

Cell[118100, 4185, 19712, 599, 290, 8715, 459, "GraphicsData", 

"PostScript", "Graphics"]

}, Open  ]]

}, Open  ]],

Cell[137839, 4788, 78, 2, 46, "Subtitle"],

Cell[137920, 4792, 377, 10, 55, "Text"]

}

]

*)









(***********************************************************************

End of Mathematica Notebook file.

***********************************************************************)



